# encoding: utf-8
# module abaqusConstantsSupplement
# from D:\SIMULIA\Abaqus\6.14-4\tools\SMApy\python2.7\lib\site-packages\abaqusConstantsSupplement.pyc
# by generator 1.147
"""
abaqusConstantsSupplement.py

This module is included by abaqusConstants and contains SymbolicConstants
required by ABAQUS that are not defined in C++
"""

# imports
import re as re  # D:\SIMULIA\Abaqus\6.14-4\tools\SMApy\python2.7\lib\re.pyc
import sys as sys  # <module 'sys' (built-in)>
import os as os  # D:\SIMULIA\Abaqus\6.14-4\tools\SMApy\python2.7\lib\os.pyc

# Variables with simple values

FALSE = False

OFF = 0

ON = 1

TRUE = True


# no functions
# classes

class AbaqusBooleanType(int):
    """
    AbaqusBoolean is derived from int, and prints as ON or OFF.
        A call to SymbolicConstant("ON/OFF") will return an AbaqusBoolean instance.
    """

    def getId(self, *args, **kwargs):  # real signature unknown
        pass

    def getText(self, *args, **kwargs):  # real signature unknown
        pass

    def isTrue(self, *args, **kwargs):  # real signature unknown
        pass

    def __copy__(self, *args, **kwargs):  # real signature unknown
        pass

    def __getstate__(self, *args, **kwargs):  # real signature unknown
        pass

    def __hash__(self, *args, **kwargs):  # real signature unknown
        pass

    def __init__(self, *args, **kwargs):  # real signature unknown
        pass

    @staticmethod  # known case of __new__
    def __new__(cls, *args, **kargs):  # reliably restored by inspect
        # no doc
        pass

    def __reduce__(self, *args, **kwargs):  # real signature unknown
        pass

    def __repr__(self, *args, **kwargs):  # real signature unknown
        pass

    def __setstate__(self, *args, **kwargs):  # real signature unknown
        pass

    def __str__(self, *args, **kwargs):  # real signature unknown
        pass

    __weakref__ = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default
    """list of weak references to the object (if defined)"""

    _abaqusBooleanOFF = 0
    _abaqusBooleanON = 1
    __dict__ = None  # (!) real value is 'dict_proxy({\'__module__\': \'symbolicConstants\', \'isTrue\': <function isTrue at 0x00000000031652E8>, \'__setstate__\': <function __setstate__ at 0x00000000031653C8>, \'__str__\': <function getText at 0x0000000003165208>, \'__reduce__\': <function __reduce__ at 0x00000000031654A8>, \'getText\': <function getText at 0x0000000003165208>, \'__dict__\': <attribute \'__dict__\' of \'AbaqusBoolean\' objects>, \'_abaqusBooleanON\': ON, \'__weakref__\': <attribute \'__weakref__\' of \'AbaqusBoolean\' objects>, \'_abaqusBooleanOFF\': OFF, \'__copy__\': <function __copy__ at 0x0000000003165438>, \'__new__\': <staticmethod object at 0x000000000314E6A8>, \'getId\': <function getId at 0x0000000003165278>, \'__init__\': <function __init__ at 0x0000000003165128>, \'__hash__\': <function __hash__ at 0x0000000003165198>, \'__getstate__\': <function __getstate__ at 0x0000000003165358>, \'__doc__\': \'\\n    AbaqusBoolean is derived from int, and prints as ON or OFF.\\n    A call to SymbolicConstant("ON/OFF") will return an AbaqusBoolean instance.\\n    \', \'__repr__\': <function getText at 0x0000000003165208>})'


AbaqusBoolean = AbaqusBooleanType


class BooleanType(int):
    """
    bool(x) -> bool

    Returns True when the argument x is true, False otherwise.
    The builtins True and False are the only two instances of the class bool.
    The class bool is a subclass of the class int, and cannot be subclassed.
    """

    def __and__(self, y):  # real signature unknown; restored from __doc__
        """ x.__and__(y) <==> x&y """
        pass

    def __init__(self, *args, **kwargs):  # real signature unknown
        pass

    @staticmethod  # known case of __new__
    def __new__(S, *more):  # real signature unknown; restored from __doc__
        """ T.__new__(S, ...) -> a new object with type S, a subtype of T """
        pass

    def __or__(self, y):  # real signature unknown; restored from __doc__
        """ x.__or__(y) <==> x|y """
        pass

    def __rand__(self, y):  # real signature unknown; restored from __doc__
        """ x.__rand__(y) <==> y&x """
        pass

    def __repr__(self):  # real signature unknown; restored from __doc__
        """ x.__repr__() <==> repr(x) """
        pass

    def __ror__(self, y):  # real signature unknown; restored from __doc__
        """ x.__ror__(y) <==> y|x """
        pass

    def __rxor__(self, y):  # real signature unknown; restored from __doc__
        """ x.__rxor__(y) <==> y^x """
        pass

    def __str__(self):  # real signature unknown; restored from __doc__
        """ x.__str__() <==> str(x) """
        pass

    def __xor__(self, y):  # real signature unknown; restored from __doc__
        """ x.__xor__(y) <==> x^y """
        pass


Boolean = BooleanType


# variables with complex values

ALL_METHODS = None  # (!) real value is 'ALL_METHODS'

ALL_TYPES = None  # (!) real value is 'ALL_TYPES'

BOTH = None  # (!) real value is 'BOTH'

EARLIEST = None  # (!) real value is 'EARLIEST'

GUI = None  # (!) real value is 'GUI'

KERNEL = None  # (!) real value is 'KERNEL'

LATEST = None  # (!) real value is 'LATEST'


class SymbolicConstantType(str):
    """
    SymbolicConstant(name <,scdId=-1>)
        Abaqus/CAE SymbolicConstant implemented in Python.
        SymbolicConstant('ON'|'OFF') will return an AbaqusBoolean instance.
    """

    def getId(self, *args, **kwargs):  # real signature unknown
        pass

    def getText(self, *args, **kwargs):  # real signature unknown
        pass

    @classmethod
    def _addToCache(cls, *args, **kwargs):  # real signature unknown
        """
        Helper method for __new__
                Also used by AbaqusBoolean.__new__
        """
        pass

    __weakref__ = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default
    """list of weak references to the object (if defined)"""

    # _cache = {
    #     'ALL_METHODS': ALL_METHODS,  # (!) forward: ALL_METHODS, real value is 'ALL_METHODS'
    #     'ALL_TYPES': ALL_TYPES,  # (!) forward: ALL_TYPES, real value is 'ALL_TYPES'
    #     'BOTH': BOTH,  # (!) forward: BOTH, real value is 'BOTH'
    #     'EARLIEST': EARLIEST,  # (!) forward: EARLIEST, real value is 'EARLIEST'
    #     'GUI': GUI,  # (!) forward: GUI, real value is 'GUI'
    #     'KERNEL': KERNEL,  # (!) forward: KERNEL, real value is 'KERNEL'
    #     'LATEST': LATEST,  # (!) forward: LATEST, real value is 'LATEST'
    #     'OFF': 0,
    #     'ON': 1,
    #     '_UNSPECIFIED': _UNSPECIFIED,
    # }
    _counter = 10
    _p = None  # (!) real value is '<_sre.SRE_Pattern object at 0x0000000003106D40>'
    __dict__ = None  # (!) real value is 'dict_proxy({\'__module__\': \'symbolicConstants\', \'__setstate__\': <function __setstate__ at 0x000000000314FDD8>, \'__str__\': <function getText at 0x000000000314FF28>, \'__reduce__\': <function __reduce__ at 0x000000000314FEB8>, \'getText\': <function getText at 0x000000000314FF28>, \'__dict__\': <attribute \'__dict__\' of \'SymbolicConstant\' objects>, \'_cache\': {\'_UNSPECIFIED\': _UNSPECIFIED, \'ON\': ON, \'OFF\': OFF, \'ALL_TYPES\': ALL_TYPES, \'BOTH\': BOTH, \'GUI\': GUI, \'ALL_METHODS\': ALL_METHODS, \'EARLIEST\': EARLIEST, \'KERNEL\': KERNEL, \'LATEST\': LATEST}, \'__lt__\': <function __lt__ at 0x000000000314FC88>, \'__weakref__\': <attribute \'__weakref__\' of \'SymbolicConstant\' objects>, \'__init__\': <function __init__ at 0x000000000314FC18>, \'_counter\': 10, \'__getstate__\': <function __getstate__ at 0x000000000314FD68>, \'__new__\': <staticmethod object at 0x000000000314E678>, \'getId\': <function getId at 0x000000000314FF98>, \'_p\': <_sre.SRE_Pattern object at 0x0000000003106D40>, \'__repr__\': <function getText at 0x000000000314FF28>, \'__hash__\': <function __hash__ at 0x000000000314FCF8>, \'__copy__\': <function __copy__ at 0x000000000314FE48>, \'_addToCache\': <classmethod object at 0x000000000314E5E8>, \'__doc__\': "\\n    SymbolicConstant(name <,scdId=-1>)\\n    Abaqus/CAE SymbolicConstant implemented in Python.\\n    SymbolicConstant(\'ON\'|\'OFF\') will return an AbaqusBoolean instance.\\n    "})'
    
    
SymbolicConstant = SymbolicConstantType


A0 = SymbolicConstant('A0')
A1 = SymbolicConstant('A1')
A2 = SymbolicConstant('A2')
A3 = SymbolicConstant('A3')
A4 = SymbolicConstant('A4')
A5 = SymbolicConstant('A5')
ABAQUS = SymbolicConstant('ABAQUS')
ABAQUS_AQUA = SymbolicConstant('ABAQUS_AQUA')
ABAQUS_BIORID = SymbolicConstant('ABAQUS_BIORID')
ABAQUS_CEL = SymbolicConstant('ABAQUS_CEL')
ABAQUS_CFD = SymbolicConstant('ABAQUS_CFD')
ABAQUS_DESIGN = SymbolicConstant('ABAQUS_DESIGN')
ABAQUS_EXPLICIT = SymbolicConstant('ABAQUS_EXPLICIT')
ABAQUS_STANDARD = SymbolicConstant('ABAQUS_STANDARD')
ABORTED = SymbolicConstant('ABORTED')
ABS = SymbolicConstant('ABS')
ABSCISSA = SymbolicConstant('ABSCISSA')
ABSOLUTE = SymbolicConstant('ABSOLUTE')
ABSOLUTE_DIFFERENCE = SymbolicConstant('ABSOLUTE_DIFFERENCE')
ABSOLUTE_DISTANCE = SymbolicConstant('ABSOLUTE_DISTANCE')
ABSOLUTE_EQUAL = SymbolicConstant('ABSOLUTE_EQUAL')
ABSOLUTE_GREATER_THAN_EQUAL = SymbolicConstant('ABSOLUTE_GREATER_THAN_EQUAL')
ABSOLUTE_GROWTH_MOVEMENT = SymbolicConstant('ABSOLUTE_GROWTH_MOVEMENT')
ABSOLUTE_LESS_THAN_EQUAL = SymbolicConstant('ABSOLUTE_LESS_THAN_EQUAL')
ABSOLUTE_SHRINK_MOVEMENT = SymbolicConstant('ABSOLUTE_SHRINK_MOVEMENT')
ABSOLUTE_VALUE = SymbolicConstant('ABSOLUTE_VALUE')
ABS_DEFAULT = SymbolicConstant('ABS_DEFAULT')
AC1D2 = SymbolicConstant('AC1D2')
AC1D3 = SymbolicConstant('AC1D3')
AC2D3 = SymbolicConstant('AC2D3')
AC2D4 = SymbolicConstant('AC2D4')
AC2D4R = SymbolicConstant('AC2D4R')
AC2D6 = SymbolicConstant('AC2D6')
AC2D8 = SymbolicConstant('AC2D8')
AC3D10 = SymbolicConstant('AC3D10')
AC3D15 = SymbolicConstant('AC3D15')
AC3D20 = SymbolicConstant('AC3D20')
AC3D4 = SymbolicConstant('AC3D4')
AC3D6 = SymbolicConstant('AC3D6')
AC3D8 = SymbolicConstant('AC3D8')
AC3D8R = SymbolicConstant('AC3D8R')
ACAX3 = SymbolicConstant('ACAX3')
ACAX4 = SymbolicConstant('ACAX4')
ACAX4R = SymbolicConstant('ACAX4R')
ACAX6 = SymbolicConstant('ACAX6')
ACAX8 = SymbolicConstant('ACAX8')
ACCELERATION = SymbolicConstant('ACCELERATION')
ACCELEROMETER = SymbolicConstant('ACCELEROMETER')
ACIN2D2 = SymbolicConstant('ACIN2D2')
ACIN2D3 = SymbolicConstant('ACIN2D3')
ACIN3D3 = SymbolicConstant('ACIN3D3')
ACIN3D4 = SymbolicConstant('ACIN3D4')
ACIN3D6 = SymbolicConstant('ACIN3D6')
ACIN3D8 = SymbolicConstant('ACIN3D8')
ACINAX2 = SymbolicConstant('ACINAX2')
ACINAX3 = SymbolicConstant('ACINAX3')
ACOUSTIC = SymbolicConstant('ACOUSTIC')
ACOUSTICS = SymbolicConstant('ACOUSTICS')
ACOUSTIC_INTENSITY = SymbolicConstant('ACOUSTIC_INTENSITY')
ACROSS = SymbolicConstant('ACROSS')
ACTIVE_CUT_RANGE = SymbolicConstant('ACTIVE_CUT_RANGE')
AC_OFF = SymbolicConstant('AC_OFF')
AC_ON = SymbolicConstant('AC_ON')
AC_PROJECTION = SymbolicConstant('AC_PROJECTION')
ADAPTIVE_MESHING = SymbolicConstant('ADAPTIVE_MESHING')
ADAPTIVE_MESH_SMOOTHING_FAILED = SymbolicConstant('ADAPTIVE_MESH_SMOOTHING_FAILED')
ADD = SymbolicConstant('ADD')
ADJUST = SymbolicConstant('ADJUST')
ADJUST_LENGTH = SymbolicConstant('ADJUST_LENGTH')
ADMITTANCE = SymbolicConstant('ADMITTANCE')
ADVANCING_FRONT = SymbolicConstant('ADVANCING_FRONT')
AFTER = SymbolicConstant('AFTER')
AGGRESSIVE = SymbolicConstant('AGGRESSIVE')
AIR_BLAST = SymbolicConstant('AIR_BLAST')
ALGORITHM = SymbolicConstant('ALGORITHM')
ALIGN = SymbolicConstant('ALIGN')
ALL = SymbolicConstant('ALL')
ALLISO = SymbolicConstant('ALLISO')
ALLOW_SUBCYCLING = SymbolicConstant('ALLOW_SUBCYCLING')
ALLSTAR = SymbolicConstant('ALLSTAR')
ALL_DAMAGE_STEPS = SymbolicConstant('ALL_DAMAGE_STEPS')
ALL_DATUMS = SymbolicConstant('ALL_DATUMS')
ALL_DIRECT = SymbolicConstant('ALL_DIRECT')
ALL_DIRECT_COMPONENTS = SymbolicConstant('ALL_DIRECT_COMPONENTS')
ALL_DISTRIB_CONTINUUM_COUPLING = SymbolicConstant('ALL_DISTRIB_CONTINUUM_COUPLING')
ALL_DISTRIB_COUPLING = SymbolicConstant('ALL_DISTRIB_COUPLING')
ALL_DISTRIB_STRUCTURAL_COUPLING = SymbolicConstant('ALL_DISTRIB_STRUCTURAL_COUPLING')
ALL_EDGES = SymbolicConstant('ALL_EDGES')
ALL_ELEMENTS = SymbolicConstant('ALL_ELEMENTS')
ALL_FRAMES = SymbolicConstant('ALL_FRAMES')
ALL_FREQUENCIES = SymbolicConstant('ALL_FREQUENCIES')
ALL_GEOMETRY = SymbolicConstant('ALL_GEOMETRY')
ALL_INCREMENTS = SymbolicConstant('ALL_INCREMENTS')
ALL_KINEM_COUPLING = SymbolicConstant('ALL_KINEM_COUPLING')
ALL_LOCATIONS = SymbolicConstant('ALL_LOCATIONS')
ALL_MODAL_STEPS = SymbolicConstant('ALL_MODAL_STEPS')
ALL_MPCS = SymbolicConstant('ALL_MPCS')
ALL_NODAL_DIAMETER = SymbolicConstant('ALL_NODAL_DIAMETER')
ALL_NODES = SymbolicConstant('ALL_NODES')
ALL_NONLINEAR_STEPS = SymbolicConstant('ALL_NONLINEAR_STEPS')
ALL_PRINCIPALS = SymbolicConstant('ALL_PRINCIPALS')
ALL_PRINCIPAL_COMPONENTS = SymbolicConstant('ALL_PRINCIPAL_COMPONENTS')
ALL_RIGID_BODY = SymbolicConstant('ALL_RIGID_BODY')
ALL_SHELL_SOLID_COUPLING = SymbolicConstant('ALL_SHELL_SOLID_COUPLING')
ALL_STATIC_STEPS = SymbolicConstant('ALL_STATIC_STEPS')
ALL_SURFACES = SymbolicConstant('ALL_SURFACES')
ALL_TIES = SymbolicConstant('ALL_TIES')
ALWAYS = SymbolicConstant('ALWAYS')
AMBIENT = SymbolicConstant('AMBIENT')
AMG = SymbolicConstant('AMG')
AMPLITUDE = SymbolicConstant('AMPLITUDE')
AMS = SymbolicConstant('AMS')
ANALYSIS = SymbolicConstant('ANALYSIS')
ANALYSIS_CHECKS = SymbolicConstant('ANALYSIS_CHECKS')
ANALYSIS_DEFAULT = SymbolicConstant('ANALYSIS_DEFAULT')
ANALYSIS_PRODUCT_DEFAULT = SymbolicConstant('ANALYSIS_PRODUCT_DEFAULT')
ANALYTICAL_FIELD = SymbolicConstant('ANALYTICAL_FIELD')
ANALYTIC_RIGID_SURFACE = SymbolicConstant('ANALYTIC_RIGID_SURFACE')
ANGLE = SymbolicConstant('ANGLE')
ANGLE_0 = SymbolicConstant('ANGLE_0')
ANGLE_45 = SymbolicConstant('ANGLE_45')
ANGLE_90 = SymbolicConstant('ANGLE_90')
ANGLE_NEG45 = SymbolicConstant('ANGLE_NEG45')
ANGULAR = SymbolicConstant('ANGULAR')
ANGULAR_DEVIATION = SymbolicConstant('ANGULAR_DEVIATION')
ANGULAR_MOMENTUM = SymbolicConstant('ANGULAR_MOMENTUM')
ANIMATION = SymbolicConstant('ANIMATION')
ANISOTROPIC = SymbolicConstant('ANISOTROPIC')
ANNEAL = SymbolicConstant('ANNEAL')
ANNEALING = SymbolicConstant('ANNEALING')
ANTIALIASING = SymbolicConstant('ANTIALIASING')
ANY_JOB = SymbolicConstant('ANY_JOB')
ANY_MESSAGE_TYPE = SymbolicConstant('ANY_MESSAGE_TYPE')
APPLY_FORCE = SymbolicConstant('APPLY_FORCE')
AQUA = SymbolicConstant('AQUA')
ARC = SymbolicConstant('ARC')
ARC_LENGTH = SymbolicConstant('ARC_LENGTH')
AREA = SymbolicConstant('AREA')
AREA_VELOCITY_SQUARED = SymbolicConstant('AREA_VELOCITY_SQUARED')
ARRAY = SymbolicConstant('ARRAY')
ARRAY_1D = SymbolicConstant('ARRAY_1D')
ARRHENIUS = SymbolicConstant('ARRHENIUS')
ARROW = SymbolicConstant('ARROW')
ARRUDA_BOYCE = SymbolicConstant('ARRUDA_BOYCE')
ASCENDING = SymbolicConstant('ASCENDING')
ASI2D2 = SymbolicConstant('ASI2D2')
ASI2D3 = SymbolicConstant('ASI2D3')
ASI3D3 = SymbolicConstant('ASI3D3')
ASI3D4 = SymbolicConstant('ASI3D4')
ASI3D6 = SymbolicConstant('ASI3D6')
ASI3D8 = SymbolicConstant('ASI3D8')
ASIAX2 = SymbolicConstant('ASIAX2')
ASIAX3 = SymbolicConstant('ASIAX3')
ASPECT_RATIO = SymbolicConstant('ASPECT_RATIO')
ASSEMBLY = SymbolicConstant('ASSEMBLY')
ASSEMBLY_LOAD = SymbolicConstant('ASSEMBLY_LOAD')
ASSEMBLY_MAP = SymbolicConstant('ASSEMBLY_MAP')
ASSEMBLY_MAP_COLORS = SymbolicConstant('ASSEMBLY_MAP_COLORS')
ASSEMBLY_SET = SymbolicConstant('ASSEMBLY_SET')
AS_DISPLAYED = SymbolicConstant('AS_DISPLAYED')
AS_IS = SymbolicConstant('AS_IS')
ATTACH_TO_POINT = SymbolicConstant('ATTACH_TO_POINT')
ATTACH_TO_REGION = SymbolicConstant('ATTACH_TO_REGION')
AT_BEGINNING = SymbolicConstant('AT_BEGINNING')
AUGMENTED_LAGRANGE = SymbolicConstant('AUGMENTED_LAGRANGE')
AUGMENTED_LAGRANGE_INCOMPATIBILITIES = SymbolicConstant('AUGMENTED_LAGRANGE_INCOMPATIBILITIES')
AUTO = SymbolicConstant('AUTO')
AUTOCAD = SymbolicConstant('AUTOCAD')
AUTOCOMPUTE = SymbolicConstant('AUTOCOMPUTE')
AUTOMATIC = SymbolicConstant('AUTOMATIC')
AUTOMATIC_EBE = SymbolicConstant('AUTOMATIC_EBE')
AUTOMATIC_GLOBAL = SymbolicConstant('AUTOMATIC_GLOBAL')
AUTO_ALIGN = SymbolicConstant('AUTO_ALIGN')
AUTO_FIT = SymbolicConstant('AUTO_FIT')
AUTO_FIT_PTS = SymbolicConstant('AUTO_FIT_PTS')
AUTO_INCREMENTATION = SymbolicConstant('AUTO_INCREMENTATION')
AUTO_TIGHT = SymbolicConstant('AUTO_TIGHT')
AVERAGE = SymbolicConstant('AVERAGE')
AVERAGE_EDGE_LENGTH = SymbolicConstant('AVERAGE_EDGE_LENGTH')
AVERAGE_SIZE = SymbolicConstant('AVERAGE_SIZE')
AVERAGE_STRAIN = SymbolicConstant('AVERAGE_STRAIN')
AVERAGE_TRANSLATION = SymbolicConstant('AVERAGE_TRANSLATION')
AVERAGING_REGION_MAP = SymbolicConstant('AVERAGING_REGION_MAP')
AVERAGING_REGION_MAP_COLORS = SymbolicConstant('AVERAGING_REGION_MAP_COLORS')
AVI = SymbolicConstant('AVI')
AXIAL = SymbolicConstant('AXIAL')
AXIAL_FORCE_CONSTRAINT = SymbolicConstant('AXIAL_FORCE_CONSTRAINT')
AXISYM = SymbolicConstant('AXISYM')
AXISYMMETRIC = SymbolicConstant('AXISYMMETRIC')
AXIS_1 = SymbolicConstant('AXIS_1')
AXIS_2 = SymbolicConstant('AXIS_2')
AXIS_3 = SymbolicConstant('AXIS_3')
B21 = SymbolicConstant('B21')
B21H = SymbolicConstant('B21H')
B22 = SymbolicConstant('B22')
B22H = SymbolicConstant('B22H')
B23 = SymbolicConstant('B23')
B23H = SymbolicConstant('B23H')
B31 = SymbolicConstant('B31')
B31H = SymbolicConstant('B31H')
B31OS = SymbolicConstant('B31OS')
B31OSH = SymbolicConstant('B31OSH')
B32 = SymbolicConstant('B32')
B32H = SymbolicConstant('B32H')
B32OS = SymbolicConstant('B32OS')
B32OSH = SymbolicConstant('B32OSH')
B33 = SymbolicConstant('B33')
B33H = SymbolicConstant('B33H')
BACKWARD_EULER = SymbolicConstant('BACKWARD_EULER')
BALANCED = SymbolicConstant('BALANCED')
BANDED = SymbolicConstant('BANDED')
BAR = SymbolicConstant('BAR')
BASE = SymbolicConstant('BASE')
BATCHPRE_PHASE = SymbolicConstant('BATCHPRE_PHASE')
BCGS = SymbolicConstant('BCGS')
BC_MAP = SymbolicConstant('BC_MAP')
BC_MAP_COLORS = SymbolicConstant('BC_MAP_COLORS')
BEAM = SymbolicConstant('BEAM')
BEAM_MPC = SymbolicConstant('BEAM_MPC')
BEFORE = SymbolicConstant('BEFORE')
BEFORE_ANALYSIS = SymbolicConstant('BEFORE_ANALYSIS')
BELOW_MIN = SymbolicConstant('BELOW_MIN')
BENDING = SymbolicConstant('BENDING')
BEST_FIT = SymbolicConstant('BEST_FIT')
BETWEEN_CAVITIES = SymbolicConstant('BETWEEN_CAVITIES')
BIASED = SymbolicConstant('BIASED')
BIAS_MAX_SIZE = SymbolicConstant('BIAS_MAX_SIZE')
BIAS_METHOD = SymbolicConstant('BIAS_METHOD')
BIAS_MIN_SIZE = SymbolicConstant('BIAS_MIN_SIZE')
BIAS_RATIO = SymbolicConstant('BIAS_RATIO')
BIAXIAL = SymbolicConstant('BIAXIAL')
BIDIRECTIONAL = SymbolicConstant('BIDIRECTIONAL')
BILINEAR = SymbolicConstant('BILINEAR')
BIMOMENT = SymbolicConstant('BIMOMENT')
BK = SymbolicConstant('BK')
BLACK_AND_WHITE = SymbolicConstant('BLACK_AND_WHITE')
BLACK_TO_WHITE = SymbolicConstant('BLACK_TO_WHITE')
BLEND = SymbolicConstant('BLEND')
BLOCKING_ALL = SymbolicConstant('BLOCKING_ALL')
BLUE_TO_RED = SymbolicConstant('BLUE_TO_RED')
BOLT = SymbolicConstant('BOLT')
BOOLEAN = SymbolicConstant('BOOLEAN')
BOTH = SymbolicConstant('BOTH')
BOTHSIDES = SymbolicConstant('BOTHSIDES')
BOTH_SIDES = SymbolicConstant('BOTH_SIDES')
BOTH_SURFACES = SymbolicConstant('BOTH_SURFACES')
BOTTOM = SymbolicConstant('BOTTOM')
BOTTOM_CENTER = SymbolicConstant('BOTTOM_CENTER')
BOTTOM_LEFT = SymbolicConstant('BOTTOM_LEFT')
BOTTOM_RIGHT = SymbolicConstant('BOTTOM_RIGHT')
BOTTOM_SURFACE = SymbolicConstant('BOTTOM_SURFACE')
BOTTOM_UP = SymbolicConstant('BOTTOM_UP')
BOUNDARY_CONDITION = SymbolicConstant('BOUNDARY_CONDITION')
BOUNDARY_ONLY = SymbolicConstant('BOUNDARY_ONLY')
BOX_OFF = SymbolicConstant('BOX_OFF')
BOX_ON = SymbolicConstant('BOX_ON')
BUCKLE = SymbolicConstant('BUCKLE')
BUCKLING_MODES = SymbolicConstant('BUCKLING_MODES')
BUILT_INTO_BASE_STATE = SymbolicConstant('BUILT_INTO_BASE_STATE')
BUILT_INTO_MODES = SymbolicConstant('BUILT_INTO_MODES')
BULK_VISCOSITY = SymbolicConstant('BULK_VISCOSITY')
BUSHING = SymbolicConstant('BUSHING')
BY_NUMBER = SymbolicConstant('BY_NUMBER')
BY_SPACING = SymbolicConstant('BY_SPACING')
C3D10 = SymbolicConstant('C3D10')
C3D10E = SymbolicConstant('C3D10E')
C3D10H = SymbolicConstant('C3D10H')
C3D10I = SymbolicConstant('C3D10I')
C3D10M = SymbolicConstant('C3D10M')
C3D10MH = SymbolicConstant('C3D10MH')
C3D10MHT = SymbolicConstant('C3D10MHT')
C3D10MP = SymbolicConstant('C3D10MP')
C3D10MPH = SymbolicConstant('C3D10MPH')
C3D10MPT = SymbolicConstant('C3D10MPT')
C3D10MT = SymbolicConstant('C3D10MT')
C3D15 = SymbolicConstant('C3D15')
C3D15E = SymbolicConstant('C3D15E')
C3D15H = SymbolicConstant('C3D15H')
C3D20 = SymbolicConstant('C3D20')
C3D20E = SymbolicConstant('C3D20E')
C3D20H = SymbolicConstant('C3D20H')
C3D20HT = SymbolicConstant('C3D20HT')
C3D20P = SymbolicConstant('C3D20P')
C3D20PH = SymbolicConstant('C3D20PH')
C3D20R = SymbolicConstant('C3D20R')
C3D20RE = SymbolicConstant('C3D20RE')
C3D20RH = SymbolicConstant('C3D20RH')
C3D20RHT = SymbolicConstant('C3D20RHT')
C3D20RP = SymbolicConstant('C3D20RP')
C3D20RPH = SymbolicConstant('C3D20RPH')
C3D20RT = SymbolicConstant('C3D20RT')
C3D20T = SymbolicConstant('C3D20T')
C3D4 = SymbolicConstant('C3D4')
C3D4E = SymbolicConstant('C3D4E')
C3D4H = SymbolicConstant('C3D4H')
C3D4P = SymbolicConstant('C3D4P')
C3D4T = SymbolicConstant('C3D4T')
C3D6 = SymbolicConstant('C3D6')
C3D6E = SymbolicConstant('C3D6E')
C3D6H = SymbolicConstant('C3D6H')
C3D6P = SymbolicConstant('C3D6P')
C3D6T = SymbolicConstant('C3D6T')
C3D8 = SymbolicConstant('C3D8')
C3D8E = SymbolicConstant('C3D8E')
C3D8H = SymbolicConstant('C3D8H')
C3D8HT = SymbolicConstant('C3D8HT')
C3D8I = SymbolicConstant('C3D8I')
C3D8IH = SymbolicConstant('C3D8IH')
C3D8P = SymbolicConstant('C3D8P')
C3D8PH = SymbolicConstant('C3D8PH')
C3D8PHT = SymbolicConstant('C3D8PHT')
C3D8PT = SymbolicConstant('C3D8PT')
C3D8R = SymbolicConstant('C3D8R')
C3D8RH = SymbolicConstant('C3D8RH')
C3D8RHT = SymbolicConstant('C3D8RHT')
C3D8RP = SymbolicConstant('C3D8RP')
C3D8RPH = SymbolicConstant('C3D8RPH')
C3D8RPHT = SymbolicConstant('C3D8RPHT')
C3D8RPT = SymbolicConstant('C3D8RPT')
C3D8RT = SymbolicConstant('C3D8RT')
C3D8T = SymbolicConstant('C3D8T')
CALCULATE = SymbolicConstant('CALCULATE')
CALCULATOR_PHASE = SymbolicConstant('CALCULATOR_PHASE')
CAMERA = SymbolicConstant('CAMERA')
CARDAN = SymbolicConstant('CARDAN')
CARMAN_KOZENY = SymbolicConstant('CARMAN_KOZENY')
CARTESIAN = SymbolicConstant('CARTESIAN')
CATEGORY_BASED = SymbolicConstant('CATEGORY_BASED')
CAVITY = SymbolicConstant('CAVITY')
CAVITY_RADIATION = SymbolicConstant('CAVITY_RADIATION')
CAVITY_RADIATION_EMMISIVITY_TOO_LARGE = SymbolicConstant('CAVITY_RADIATION_EMMISIVITY_TOO_LARGE')
CAVITY_RADIATION_PARALLEL_DECOMPOSITION = SymbolicConstant('CAVITY_RADIATION_PARALLEL_DECOMPOSITION')
CAX3 = SymbolicConstant('CAX3')
CAX3E = SymbolicConstant('CAX3E')
CAX3H = SymbolicConstant('CAX3H')
CAX3T = SymbolicConstant('CAX3T')
CAX4 = SymbolicConstant('CAX4')
CAX4E = SymbolicConstant('CAX4E')
CAX4H = SymbolicConstant('CAX4H')
CAX4HT = SymbolicConstant('CAX4HT')
CAX4I = SymbolicConstant('CAX4I')
CAX4IH = SymbolicConstant('CAX4IH')
CAX4P = SymbolicConstant('CAX4P')
CAX4PH = SymbolicConstant('CAX4PH')
CAX4R = SymbolicConstant('CAX4R')
CAX4RH = SymbolicConstant('CAX4RH')
CAX4RHT = SymbolicConstant('CAX4RHT')
CAX4RP = SymbolicConstant('CAX4RP')
CAX4RPH = SymbolicConstant('CAX4RPH')
CAX4RT = SymbolicConstant('CAX4RT')
CAX4T = SymbolicConstant('CAX4T')
CAX6 = SymbolicConstant('CAX6')
CAX6E = SymbolicConstant('CAX6E')
CAX6H = SymbolicConstant('CAX6H')
CAX6M = SymbolicConstant('CAX6M')
CAX6MH = SymbolicConstant('CAX6MH')
CAX6MHT = SymbolicConstant('CAX6MHT')
CAX6MP = SymbolicConstant('CAX6MP')
CAX6MPH = SymbolicConstant('CAX6MPH')
CAX6MT = SymbolicConstant('CAX6MT')
CAX8 = SymbolicConstant('CAX8')
CAX8E = SymbolicConstant('CAX8E')
CAX8H = SymbolicConstant('CAX8H')
CAX8HT = SymbolicConstant('CAX8HT')
CAX8P = SymbolicConstant('CAX8P')
CAX8PH = SymbolicConstant('CAX8PH')
CAX8R = SymbolicConstant('CAX8R')
CAX8RE = SymbolicConstant('CAX8RE')
CAX8RH = SymbolicConstant('CAX8RH')
CAX8RHT = SymbolicConstant('CAX8RHT')
CAX8RP = SymbolicConstant('CAX8RP')
CAX8RPH = SymbolicConstant('CAX8RPH')
CAX8RT = SymbolicConstant('CAX8RT')
CAX8T = SymbolicConstant('CAX8T')
CAXA41 = SymbolicConstant('CAXA41')
CAXA42 = SymbolicConstant('CAXA42')
CAXA43 = SymbolicConstant('CAXA43')
CAXA44 = SymbolicConstant('CAXA44')
CAXA4H1 = SymbolicConstant('CAXA4H1')
CAXA4H2 = SymbolicConstant('CAXA4H2')
CAXA4H3 = SymbolicConstant('CAXA4H3')
CAXA4H4 = SymbolicConstant('CAXA4H4')
CAXA4R1 = SymbolicConstant('CAXA4R1')
CAXA4R2 = SymbolicConstant('CAXA4R2')
CAXA4R3 = SymbolicConstant('CAXA4R3')
CAXA4R4 = SymbolicConstant('CAXA4R4')
CAXA4RH1 = SymbolicConstant('CAXA4RH1')
CAXA4RH2 = SymbolicConstant('CAXA4RH2')
CAXA4RH3 = SymbolicConstant('CAXA4RH3')
CAXA4RH4 = SymbolicConstant('CAXA4RH4')
CAXA81 = SymbolicConstant('CAXA81')
CAXA82 = SymbolicConstant('CAXA82')
CAXA83 = SymbolicConstant('CAXA83')
CAXA84 = SymbolicConstant('CAXA84')
CAXA8H1 = SymbolicConstant('CAXA8H1')
CAXA8H2 = SymbolicConstant('CAXA8H2')
CAXA8H3 = SymbolicConstant('CAXA8H3')
CAXA8H4 = SymbolicConstant('CAXA8H4')
CAXA8P1 = SymbolicConstant('CAXA8P1')
CAXA8P2 = SymbolicConstant('CAXA8P2')
CAXA8P3 = SymbolicConstant('CAXA8P3')
CAXA8P4 = SymbolicConstant('CAXA8P4')
CAXA8R1 = SymbolicConstant('CAXA8R1')
CAXA8R2 = SymbolicConstant('CAXA8R2')
CAXA8R3 = SymbolicConstant('CAXA8R3')
CAXA8R4 = SymbolicConstant('CAXA8R4')
CAXA8RH1 = SymbolicConstant('CAXA8RH1')
CAXA8RH2 = SymbolicConstant('CAXA8RH2')
CAXA8RH3 = SymbolicConstant('CAXA8RH3')
CAXA8RH4 = SymbolicConstant('CAXA8RH4')
CAXA8RP1 = SymbolicConstant('CAXA8RP1')
CAXA8RP2 = SymbolicConstant('CAXA8RP2')
CAXA8RP3 = SymbolicConstant('CAXA8RP3')
CAXA8RP4 = SymbolicConstant('CAXA8RP4')
CCL12 = SymbolicConstant('CCL12')
CCL12H = SymbolicConstant('CCL12H')
CCL18 = SymbolicConstant('CCL18')
CCL18H = SymbolicConstant('CCL18H')
CCL24 = SymbolicConstant('CCL24')
CCL24H = SymbolicConstant('CCL24H')
CCL24R = SymbolicConstant('CCL24R')
CCL24RH = SymbolicConstant('CCL24RH')
CCL9 = SymbolicConstant('CCL9')
CCL9H = SymbolicConstant('CCL9H')
CCW = SymbolicConstant('CCW')
CENTER = SymbolicConstant('CENTER')
CENTER_LEFT = SymbolicConstant('CENTER_LEFT')
CENTER_OF_MASS = SymbolicConstant('CENTER_OF_MASS')
CENTER_RIGHT = SymbolicConstant('CENTER_RIGHT')
CENTROID = SymbolicConstant('CENTROID')
CFD = SymbolicConstant('CFD')
CFD_ANALYSIS = SymbolicConstant('CFD_ANALYSIS')
CFD_PHASE = SymbolicConstant('CFD_PHASE')
CG = SymbolicConstant('CG')
CGAX3 = SymbolicConstant('CGAX3')
CGAX3H = SymbolicConstant('CGAX3H')
CGAX3HT = SymbolicConstant('CGAX3HT')
CGAX3T = SymbolicConstant('CGAX3T')
CGAX4 = SymbolicConstant('CGAX4')
CGAX4H = SymbolicConstant('CGAX4H')
CGAX4HT = SymbolicConstant('CGAX4HT')
CGAX4R = SymbolicConstant('CGAX4R')
CGAX4RH = SymbolicConstant('CGAX4RH')
CGAX4RHT = SymbolicConstant('CGAX4RHT')
CGAX4RT = SymbolicConstant('CGAX4RT')
CGAX4T = SymbolicConstant('CGAX4T')
CGAX6 = SymbolicConstant('CGAX6')
CGAX6H = SymbolicConstant('CGAX6H')
CGAX6M = SymbolicConstant('CGAX6M')
CGAX6MH = SymbolicConstant('CGAX6MH')
CGAX6MHT = SymbolicConstant('CGAX6MHT')
CGAX6MT = SymbolicConstant('CGAX6MT')
CGAX8 = SymbolicConstant('CGAX8')
CGAX8H = SymbolicConstant('CGAX8H')
CGAX8HT = SymbolicConstant('CGAX8HT')
CGAX8R = SymbolicConstant('CGAX8R')
CGAX8RH = SymbolicConstant('CGAX8RH')
CGAX8RHT = SymbolicConstant('CGAX8RHT')
CGAX8RT = SymbolicConstant('CGAX8RT')
CGAX8T = SymbolicConstant('CGAX8T')
CGPE10 = SymbolicConstant('CGPE10')
CGPE10H = SymbolicConstant('CGPE10H')
CGPE10R = SymbolicConstant('CGPE10R')
CGPE10RH = SymbolicConstant('CGPE10RH')
CGPE5 = SymbolicConstant('CGPE5')
CGPE5H = SymbolicConstant('CGPE5H')
CGPE6 = SymbolicConstant('CGPE6')
CGPE6H = SymbolicConstant('CGPE6H')
CGPE6I = SymbolicConstant('CGPE6I')
CGPE6IH = SymbolicConstant('CGPE6IH')
CGPE6MH = SymbolicConstant('CGPE6MH')
CGPE6R = SymbolicConstant('CGPE6R')
CGPE6RH = SymbolicConstant('CGPE6RH')
CGPE8 = SymbolicConstant('CGPE8')
CGPE8H = SymbolicConstant('CGPE8H')
CHEBYCHEV = SymbolicConstant('CHEBYCHEV')
CHECKER = SymbolicConstant('CHECKER')
CHECK_COMPLETED = SymbolicConstant('CHECK_COMPLETED')
CHECK_RUNNING = SymbolicConstant('CHECK_RUNNING')
CHECK_SUBMITTED = SymbolicConstant('CHECK_SUBMITTED')
CINAX4 = SymbolicConstant('CINAX4')
CINAX5R = SymbolicConstant('CINAX5R')
CINPE4 = SymbolicConstant('CINPE4')
CINPE5R = SymbolicConstant('CINPE5R')
CINPS4 = SymbolicConstant('CINPS4')
CINPS5R = SymbolicConstant('CINPS5R')
CIRCLE = SymbolicConstant('CIRCLE')
CIRCLE_RADIUS = SymbolicConstant('CIRCLE_RADIUS')
CIRCULAR = SymbolicConstant('CIRCULAR')
CIRCUM = SymbolicConstant('CIRCUM')
CIRCUMF = SymbolicConstant('CIRCUMF')
CIRCUMFERENTIAL = SymbolicConstant('CIRCUMFERENTIAL')
CIRC_MIRROR_RECT = SymbolicConstant('CIRC_MIRROR_RECT')
CIRC_RECT_MIRROR = SymbolicConstant('CIRC_RECT_MIRROR')
CLEARANCE = SymbolicConstant('CLEARANCE')
CLOCKWISE = SymbolicConstant('CLOCKWISE')
CLOSEST = SymbolicConstant('CLOSEST')
CLOSEST_POINT_FRACTION = SymbolicConstant('CLOSEST_POINT_FRACTION')
CLOSURE_VALUE = SymbolicConstant('CLOSURE_VALUE')
COARSE = SymbolicConstant('COARSE')
COD = SymbolicConstant('COD')
CODEC = SymbolicConstant('CODEC')
COEFFICIENT = SymbolicConstant('COEFFICIENT')
COEFFICIENTS = SymbolicConstant('COEFFICIENTS')
COH2D4 = SymbolicConstant('COH2D4')
COH2D4P = SymbolicConstant('COH2D4P')
COH3D6 = SymbolicConstant('COH3D6')
COH3D6P = SymbolicConstant('COH3D6P')
COH3D8 = SymbolicConstant('COH3D8')
COH3D8P = SymbolicConstant('COH3D8P')
COHAX4 = SymbolicConstant('COHAX4')
COHAX4P = SymbolicConstant('COHAX4P')
COLOR = SymbolicConstant('COLOR')
COMBINED = SymbolicConstant('COMBINED')
COMMA_SEPARATED_VALUES = SymbolicConstant('COMMA_SEPARATED_VALUES')
COMPLETED = SymbolicConstant('COMPLETED')
COMPLEX = SymbolicConstant('COMPLEX')
COMPLEX_EIGENSOLVER = SymbolicConstant('COMPLEX_EIGENSOLVER')
COMPLEX_FREQUENCY = SymbolicConstant('COMPLEX_FREQUENCY')
COMPLEX_MAGNITUDE = SymbolicConstant('COMPLEX_MAGNITUDE')
COMPLEX_PHASE = SymbolicConstant('COMPLEX_PHASE')
COMPLEX_VAL_AT_ANGLE = SymbolicConstant('COMPLEX_VAL_AT_ANGLE')
COMPONENT = SymbolicConstant('COMPONENT')
COMPONENT_NUMBER = SymbolicConstant('COMPONENT_NUMBER')
COMPRESSEDINDEX = SymbolicConstant('COMPRESSEDINDEX')
COMPRESSED_VRML = SymbolicConstant('COMPRESSED_VRML')
COMPRESSIBLE = SymbolicConstant('COMPRESSIBLE')
COMPRESSION = SymbolicConstant('COMPRESSION')
COMPUTE = SymbolicConstant('COMPUTE')
COMPUTED = SymbolicConstant('COMPUTED')
COMPUTED_TOLERANCE = SymbolicConstant('COMPUTED_TOLERANCE')
COMP_DEFAULT = SymbolicConstant('COMP_DEFAULT')
CONCENTRIC = SymbolicConstant('CONCENTRIC')
CONDITION_BASED_OPTIMIZATION = SymbolicConstant('CONDITION_BASED_OPTIMIZATION')
CONN2D2 = SymbolicConstant('CONN2D2')
CONN3D2 = SymbolicConstant('CONN3D2')
CONNECTOR = SymbolicConstant('CONNECTOR')
CONNECTOR_MAP = SymbolicConstant('CONNECTOR_MAP')
CONNECTOR_MAP_COLORS = SymbolicConstant('CONNECTOR_MAP_COLORS')
CONNECTOR_PROP_MAP = SymbolicConstant('CONNECTOR_PROP_MAP')
CONNECTOR_PROP_MAP_COLORS = SymbolicConstant('CONNECTOR_PROP_MAP_COLORS')
CONNECTOR_TYPE_MAP = SymbolicConstant('CONNECTOR_TYPE_MAP')
CONNECTOR_TYPE_MAP_COLORS = SymbolicConstant('CONNECTOR_TYPE_MAP_COLORS')
CONSERVATIVE = SymbolicConstant('CONSERVATIVE')
CONSOLIDATION = SymbolicConstant('CONSOLIDATION')
CONSTANT = SymbolicConstant('CONSTANT')
CONSTANTPRESSURE = SymbolicConstant('CONSTANTPRESSURE')
CONSTANTS = SymbolicConstant('CONSTANTS')
CONSTANTVOLUME = SymbolicConstant('CONSTANTVOLUME')
CONSTANT_RATIO = SymbolicConstant('CONSTANT_RATIO')
CONSTANT_THROUGH_THICKNESS = SymbolicConstant('CONSTANT_THROUGH_THICKNESS')
CONSTANT_VELOCITY = SymbolicConstant('CONSTANT_VELOCITY')
CONSTRAINED_LAPLACIAN = SymbolicConstant('CONSTRAINED_LAPLACIAN')
CONSTRAINT = SymbolicConstant('CONSTRAINT')
CONSTRAINT_MAP = SymbolicConstant('CONSTRAINT_MAP')
CONSTRAINT_MAP_COLORS = SymbolicConstant('CONSTRAINT_MAP_COLORS')
CONSTRAINT_TYPE_MAP = SymbolicConstant('CONSTRAINT_TYPE_MAP')
CONSTRAINT_TYPE_MAP_COLORS = SymbolicConstant('CONSTRAINT_TYPE_MAP_COLORS')
CONSTRUCTION = SymbolicConstant('CONSTRUCTION')
CONTACT = SymbolicConstant('CONTACT')
CONTACT_ALL = SymbolicConstant('CONTACT_ALL')
CONTACT_EXPLICIT = SymbolicConstant('CONTACT_EXPLICIT')
CONTACT_PRESELECT = SymbolicConstant('CONTACT_PRESELECT')
CONTACT_STANDARD = SymbolicConstant('CONTACT_STANDARD')
CONTINUE = SymbolicConstant('CONTINUE')
CONTINUOUS = SymbolicConstant('CONTINUOUS')
CONTINUUM = SymbolicConstant('CONTINUUM')
CONTINUUM_SHELL = SymbolicConstant('CONTINUUM_SHELL')
CONTOURS_ON_DEF = SymbolicConstant('CONTOURS_ON_DEF')
CONTOURS_ON_UNDEF = SymbolicConstant('CONTOURS_ON_UNDEF')
CONTROL_POINTS = SymbolicConstant('CONTROL_POINTS')
CONVERGENCE = SymbolicConstant('CONVERGENCE')
CONVERT_SDI_OFF = SymbolicConstant('CONVERT_SDI_OFF')
CONVERT_SDI_ON = SymbolicConstant('CONVERT_SDI_ON')
CONWEP = SymbolicConstant('CONWEP')
COORDINATE = SymbolicConstant('COORDINATE')
COPLANAR_EDGES = SymbolicConstant('COPLANAR_EDGES')
CORIOLIS_LOAD = SymbolicConstant('CORIOLIS_LOAD')
CORRECTION_ACCEPTED = SymbolicConstant('CORRECTION_ACCEPTED')
CORRECTION_ACCEPTED_ESTIMATED_CORRECTION = SymbolicConstant('CORRECTION_ACCEPTED_ESTIMATED_CORRECTION')
CORRECTION_ACCEPTED_SMALL_INCREMENT = SymbolicConstant('CORRECTION_ACCEPTED_SMALL_INCREMENT')
CORRECTION_NOT_ACCEPTED = SymbolicConstant('CORRECTION_NOT_ACCEPTED')
CORRELATED = SymbolicConstant('CORRELATED')
COSINE = SymbolicConstant('COSINE')
COUNT = SymbolicConstant('COUNT')
COUNTERCLOCKWISE = SymbolicConstant('COUNTERCLOCKWISE')
COUPLED = SymbolicConstant('COUPLED')
COUPLED_MOTION = SymbolicConstant('COUPLED_MOTION')
COUPLED_POSITION = SymbolicConstant('COUPLED_POSITION')
COUPLED_TEMP_DISPLACEMENT = SymbolicConstant('COUPLED_TEMP_DISPLACEMENT')
COUPLED_THERMAL_ELECTRIC = SymbolicConstant('COUPLED_THERMAL_ELECTRIC')
COUPLED_THERMAL_ELECTRICAL = SymbolicConstant('COUPLED_THERMAL_ELECTRICAL')
COUPLED_THERMAL_ELECTRICAL_STRUCTURAL = SymbolicConstant('COUPLED_THERMAL_ELECTRICAL_STRUCTURAL')
COUPLED_THERMAL_STRESS = SymbolicConstant('COUPLED_THERMAL_STRESS')
COUPLED_TRACTION = SymbolicConstant('COUPLED_TRACTION')
COUPLING_FORCE_CONSTRAINT = SymbolicConstant('COUPLING_FORCE_CONSTRAINT')
COUPLING_MOMENT_CONSTRAINT = SymbolicConstant('COUPLING_MOMENT_CONSTRAINT')
CPE3 = SymbolicConstant('CPE3')
CPE3E = SymbolicConstant('CPE3E')
CPE3H = SymbolicConstant('CPE3H')
CPE3T = SymbolicConstant('CPE3T')
CPE4 = SymbolicConstant('CPE4')
CPE4E = SymbolicConstant('CPE4E')
CPE4H = SymbolicConstant('CPE4H')
CPE4HT = SymbolicConstant('CPE4HT')
CPE4I = SymbolicConstant('CPE4I')
CPE4IH = SymbolicConstant('CPE4IH')
CPE4P = SymbolicConstant('CPE4P')
CPE4PH = SymbolicConstant('CPE4PH')
CPE4R = SymbolicConstant('CPE4R')
CPE4RH = SymbolicConstant('CPE4RH')
CPE4RHT = SymbolicConstant('CPE4RHT')
CPE4RP = SymbolicConstant('CPE4RP')
CPE4RPH = SymbolicConstant('CPE4RPH')
CPE4RT = SymbolicConstant('CPE4RT')
CPE4T = SymbolicConstant('CPE4T')
CPE6 = SymbolicConstant('CPE6')
CPE6E = SymbolicConstant('CPE6E')
CPE6H = SymbolicConstant('CPE6H')
CPE6M = SymbolicConstant('CPE6M')
CPE6MH = SymbolicConstant('CPE6MH')
CPE6MHT = SymbolicConstant('CPE6MHT')
CPE6MP = SymbolicConstant('CPE6MP')
CPE6MPH = SymbolicConstant('CPE6MPH')
CPE6MT = SymbolicConstant('CPE6MT')
CPE8 = SymbolicConstant('CPE8')
CPE8E = SymbolicConstant('CPE8E')
CPE8H = SymbolicConstant('CPE8H')
CPE8HT = SymbolicConstant('CPE8HT')
CPE8P = SymbolicConstant('CPE8P')
CPE8PH = SymbolicConstant('CPE8PH')
CPE8R = SymbolicConstant('CPE8R')
CPE8RE = SymbolicConstant('CPE8RE')
CPE8RH = SymbolicConstant('CPE8RH')
CPE8RHT = SymbolicConstant('CPE8RHT')
CPE8RP = SymbolicConstant('CPE8RP')
CPE8RPH = SymbolicConstant('CPE8RPH')
CPE8RT = SymbolicConstant('CPE8RT')
CPE8T = SymbolicConstant('CPE8T')
CPEG3 = SymbolicConstant('CPEG3')
CPEG3H = SymbolicConstant('CPEG3H')
CPEG3HT = SymbolicConstant('CPEG3HT')
CPEG3T = SymbolicConstant('CPEG3T')
CPEG4 = SymbolicConstant('CPEG4')
CPEG4H = SymbolicConstant('CPEG4H')
CPEG4HT = SymbolicConstant('CPEG4HT')
CPEG4I = SymbolicConstant('CPEG4I')
CPEG4IH = SymbolicConstant('CPEG4IH')
CPEG4R = SymbolicConstant('CPEG4R')
CPEG4RH = SymbolicConstant('CPEG4RH')
CPEG4RT = SymbolicConstant('CPEG4RT')
CPEG4RHT = SymbolicConstant('CPEG4RHT')
CPEG4T = SymbolicConstant('CPEG4T')
CPEG6 = SymbolicConstant('CPEG6')
CPEG6H = SymbolicConstant('CPEG6H')
CPEG6M = SymbolicConstant('CPEG6M')
CPEG6MH = SymbolicConstant('CPEG6MH')
CPEG6MHT = SymbolicConstant('CPEG6MHT')
CPEG6MT = SymbolicConstant('CPEG6MT')
CPEG8 = SymbolicConstant('CPEG8')
CPEG8H = SymbolicConstant('CPEG8H')
CPEG8HT = SymbolicConstant('CPEG8HT')
CPEG8R = SymbolicConstant('CPEG8R')
CPEG8RH = SymbolicConstant('CPEG8RH')
CPEG8RT = SymbolicConstant('CPEG8RT')
CPEG8RHT = SymbolicConstant('CPEG8RHT')
CPEG8T = SymbolicConstant('CPEG8T')
CPS3 = SymbolicConstant('CPS3')
CPS3E = SymbolicConstant('CPS3E')
CPS3T = SymbolicConstant('CPS3T')
CPS4 = SymbolicConstant('CPS4')
CPS4E = SymbolicConstant('CPS4E')
CPS4I = SymbolicConstant('CPS4I')
CPS4R = SymbolicConstant('CPS4R')
CPS4RT = SymbolicConstant('CPS4RT')
CPS4T = SymbolicConstant('CPS4T')
CPS6 = SymbolicConstant('CPS6')
CPS6E = SymbolicConstant('CPS6E')
CPS6M = SymbolicConstant('CPS6M')
CPS6MT = SymbolicConstant('CPS6MT')
CPS8 = SymbolicConstant('CPS8')
CPS8E = SymbolicConstant('CPS8E')
CPS8R = SymbolicConstant('CPS8R')
CPS8RE = SymbolicConstant('CPS8RE')
CPS8RT = SymbolicConstant('CPS8RT')
CPS8T = SymbolicConstant('CPS8T')
CPU_TIME_XPL = SymbolicConstant('CPU_TIME_XPL')
CQC = SymbolicConstant('CQC')
CRACKTIP = SymbolicConstant('CRACKTIP')
CRACK_GROWTH = SymbolicConstant('CRACK_GROWTH')
CRACK_LENGTH = SymbolicConstant('CRACK_LENGTH')
CRACK_NORMAL = SymbolicConstant('CRACK_NORMAL')
CREATED = SymbolicConstant('CREATED')
CREEP = SymbolicConstant('CREEP')
CREEP_OFF = SymbolicConstant('CREEP_OFF')
CREEP_TEST_DATA = SymbolicConstant('CREEP_TEST_DATA')
CRITICAL_DAMPING_FRACTION = SymbolicConstant('CRITICAL_DAMPING_FRACTION')
CRITICAL_STRESS = SymbolicConstant('CRITICAL_STRESS')
CROSS = SymbolicConstant('CROSS')
CROSSED_SURFACES = SymbolicConstant('CROSSED_SURFACES')
CROSSING_VALUE = SymbolicConstant('CROSSING_VALUE')
CRUSHABLE_FOAM = SymbolicConstant('CRUSHABLE_FOAM')
CSYS = SymbolicConstant('CSYS')
CUBIC = SymbolicConstant('CUBIC')
CUBIC_SPLINE = SymbolicConstant('CUBIC_SPLINE')
CURRENT = SymbolicConstant('CURRENT')
CURRENT_DISPLAY_GROUP = SymbolicConstant('CURRENT_DISPLAY_GROUP')
CURRENT_FRAME = SymbolicConstant('CURRENT_FRAME')
CURVATURE = SymbolicConstant('CURVATURE')
CURVATURE_BASED_BY_SIZE = SymbolicConstant('CURVATURE_BASED_BY_SIZE')
CURVE_LEGEND = SymbolicConstant('CURVE_LEGEND')
CURVE_NAME = SymbolicConstant('CURVE_NAME')
CURVE_NAME_LEGEND = SymbolicConstant('CURVE_NAME_LEGEND')
CUSTOM = SymbolicConstant('CUSTOM')
CUT = SymbolicConstant('CUT')
CUT_OFF = SymbolicConstant('CUT_OFF')
CVJOINT = SymbolicConstant('CVJOINT')
CW = SymbolicConstant('CW')
CYCLIC_SYMMETRY = SymbolicConstant('CYCLIC_SYMMETRY')
CYLINDER = SymbolicConstant('CYLINDER')
CYLINDRICAL = SymbolicConstant('CYLINDRICAL')
C_INTEGRAL = SymbolicConstant('C_INTEGRAL')
DAMAGE = SymbolicConstant('DAMAGE')
DAMAGE_CRITERION = SymbolicConstant('DAMAGE_CRITERION')
DAMPING_COEFFICIENT = SymbolicConstant('DAMPING_COEFFICIENT')
DAMPING_FACTOR = SymbolicConstant('DAMPING_FACTOR')
DASHED = SymbolicConstant('DASHED')
DASHPOT1 = SymbolicConstant('DASHPOT1')
DASHPOT2 = SymbolicConstant('DASHPOT2')
DASHPOTA = SymbolicConstant('DASHPOTA')
DATACHECK = SymbolicConstant('DATACHECK')
DATUM = SymbolicConstant('DATUM')
DB = SymbolicConstant('DB')
DB2 = SymbolicConstant('DB2')
DC1D2 = SymbolicConstant('DC1D2')
DC1D2E = SymbolicConstant('DC1D2E')
DC1D3 = SymbolicConstant('DC1D3')
DC1D3E = SymbolicConstant('DC1D3E')
DC2D3 = SymbolicConstant('DC2D3')
DC2D3E = SymbolicConstant('DC2D3E')
DC2D4 = SymbolicConstant('DC2D4')
DC2D4E = SymbolicConstant('DC2D4E')
DC2D6 = SymbolicConstant('DC2D6')
DC2D6E = SymbolicConstant('DC2D6E')
DC2D8 = SymbolicConstant('DC2D8')
DC2D8E = SymbolicConstant('DC2D8E')
DC3D10 = SymbolicConstant('DC3D10')
DC3D10E = SymbolicConstant('DC3D10E')
DC3D15 = SymbolicConstant('DC3D15')
DC3D15E = SymbolicConstant('DC3D15E')
DC3D20 = SymbolicConstant('DC3D20')
DC3D20E = SymbolicConstant('DC3D20E')
DC3D4 = SymbolicConstant('DC3D4')
DC3D4E = SymbolicConstant('DC3D4E')
DC3D6 = SymbolicConstant('DC3D6')
DC3D6E = SymbolicConstant('DC3D6E')
DC3D8 = SymbolicConstant('DC3D8')
DC3D8E = SymbolicConstant('DC3D8E')
DCAX3 = SymbolicConstant('DCAX3')
DCAX3E = SymbolicConstant('DCAX3E')
DCAX4 = SymbolicConstant('DCAX4')
DCAX4E = SymbolicConstant('DCAX4E')
DCAX6 = SymbolicConstant('DCAX6')
DCAX6E = SymbolicConstant('DCAX6E')
DCAX8 = SymbolicConstant('DCAX8')
DCAX8E = SymbolicConstant('DCAX8E')
DCC1D2 = SymbolicConstant('DCC1D2')
DCC1D2D = SymbolicConstant('DCC1D2D')
DCC2D4 = SymbolicConstant('DCC2D4')
DCC2D4D = SymbolicConstant('DCC2D4D')
DCC3D8 = SymbolicConstant('DCC3D8')
DCC3D8D = SymbolicConstant('DCC3D8D')
DCCAX2 = SymbolicConstant('DCCAX2')
DCCAX2D = SymbolicConstant('DCCAX2D')
DCCAX4 = SymbolicConstant('DCCAX4')
DCCAX4D = SymbolicConstant('DCCAX4D')
DCOUP2D = SymbolicConstant('DCOUP2D')
DCOUP3D = SymbolicConstant('DCOUP3D')
DDM_ITERATIVE = SymbolicConstant('DDM_ITERATIVE')
DEACTIVATED = SymbolicConstant('DEACTIVATED')
DEACTIVATED_FROM_BASE_STATE = SymbolicConstant('DEACTIVATED_FROM_BASE_STATE')
DEBONDING = SymbolicConstant('DEBONDING')
DECIMAL = SymbolicConstant('DECIMAL')
DEFAULT = SymbolicConstant('DEFAULT')
DEFAULTFORMAT = SymbolicConstant('DEFAULTFORMAT')
DEFAULT_COLORS = SymbolicConstant('DEFAULT_COLORS')
DEFAULT_LIMIT = SymbolicConstant('DEFAULT_LIMIT')
DEFAULT_MODEL = SymbolicConstant('DEFAULT_MODEL')
DEFAULT_SIZE = SymbolicConstant('DEFAULT_SIZE')
DEFINE = SymbolicConstant('DEFINE')
DEFORMABLE_BODY = SymbolicConstant('DEFORMABLE_BODY')
DEFORMED = SymbolicConstant('DEFORMED')
DELAYED = SymbolicConstant('DELAYED')
DELETE = SymbolicConstant('DELETE')
DELTA_OVER_1_ITERATION = SymbolicConstant('DELTA_OVER_1_ITERATION')
DELTA_OVER_2_ITERATIONS = SymbolicConstant('DELTA_OVER_2_ITERATIONS')
DELTA_OVER_3_ITERATIONS = SymbolicConstant('DELTA_OVER_3_ITERATIONS')
DELTA_OVER_4_ITERATIONS = SymbolicConstant('DELTA_OVER_4_ITERATIONS')
DELTA_OVER_5_ITERATIONS = SymbolicConstant('DELTA_OVER_5_ITERATIONS')
DELTA_OVER_6_ITERATIONS = SymbolicConstant('DELTA_OVER_6_ITERATIONS')
DEMOLD_REGION = SymbolicConstant('DEMOLD_REGION')
DENSITY = SymbolicConstant('DENSITY')
DENSITY_ROTATIONAL_ACCELERATION = SymbolicConstant('DENSITY_ROTATIONAL_ACCELERATION')
DERIVED_COMPONENT = SymbolicConstant('DERIVED_COMPONENT')
DESCENDING = SymbolicConstant('DESCENDING')
DESIGN_SENSITIVITY = SymbolicConstant('DESIGN_SENSITIVITY')
DEVIATION_FACTOR = SymbolicConstant('DEVIATION_FACTOR')
DGAP = SymbolicConstant('DGAP')
DIFFERENCE = SymbolicConstant('DIFFERENCE')
DIFFUSE = SymbolicConstant('DIFFUSE')
DIRECT = SymbolicConstant('DIRECT')
DIRECTION = SymbolicConstant('DIRECTION')
DIRECTIONAL = SymbolicConstant('DIRECTIONAL')
DIRECTION_COSINE = SymbolicConstant('DIRECTION_COSINE')
DIRECT_COMPONENT = SymbolicConstant('DIRECT_COMPONENT')
DIRECT_CYCLIC = SymbolicConstant('DIRECT_CYCLIC')
DIRECT_INCREMENTATION = SymbolicConstant('DIRECT_INCREMENTATION')
DIRECT_NO_STOP_INCREMENTATION = SymbolicConstant('DIRECT_NO_STOP_INCREMENTATION')
DIRECT_SOLVER = SymbolicConstant('DIRECT_SOLVER')
DIRECT_STEADY_STATE_DYNAMIC = SymbolicConstant('DIRECT_STEADY_STATE_DYNAMIC')
DIRECT_SYMMETRIC = SymbolicConstant('DIRECT_SYMMETRIC')
DIRECT_UNSYMMETRIC = SymbolicConstant('DIRECT_UNSYMMETRIC')
DISABLED_BY_SYSTEM = SymbolicConstant('DISABLED_BY_SYSTEM')
DISABLED_BY_USER = SymbolicConstant('DISABLED_BY_USER')
DISABLE_THROUGHOUT_STEP = SymbolicConstant('DISABLE_THROUGHOUT_STEP')
DISCONTINUITIES = SymbolicConstant('DISCONTINUITIES')
DISCRETE = SymbolicConstant('DISCRETE')
DISCRETE_FIELD = SymbolicConstant('DISCRETE_FIELD')
DISCRETE_RIGID_SURFACE = SymbolicConstant('DISCRETE_RIGID_SURFACE')
DISK = SymbolicConstant('DISK')
DISPLACEMENT = SymbolicConstant('DISPLACEMENT')
DISPLACEMENT_FIELD = SymbolicConstant('DISPLACEMENT_FIELD')
DISPLAY_GROUPS = SymbolicConstant('DISPLAY_GROUPS')
DISPLAY_GRP_MAP = SymbolicConstant('DISPLAY_GRP_MAP')
DISPLAY_GRP_MAP_COLORS = SymbolicConstant('DISPLAY_GRP_MAP_COLORS')
DISSIPATED_ENERGY_FRACTION = SymbolicConstant('DISSIPATED_ENERGY_FRACTION')
DISTRIBUTING = SymbolicConstant('DISTRIBUTING')
DISTRIBUTING_COUPLING = SymbolicConstant('DISTRIBUTING_COUPLING')
DIVIDE = SymbolicConstant('DIVIDE')
DMASS_XPL = SymbolicConstant('DMASS_XPL')
DOF_MODE = SymbolicConstant('DOF_MODE')
DOF_MODE_MPC = SymbolicConstant('DOF_MODE_MPC')
DOMAIN = SymbolicConstant('DOMAIN')
DOTTED = SymbolicConstant('DOTTED')
DOT_DASH = SymbolicConstant('DOT_DASH')
DOUBLE = SymbolicConstant('DOUBLE')
DOUBLE_CONSTRAINT_ONLY = SymbolicConstant('DOUBLE_CONSTRAINT_ONLY')
DOUBLE_PLUS_PACK = SymbolicConstant('DOUBLE_PLUS_PACK')
DOUBLE_PRECISION = SymbolicConstant('DOUBLE_PRECISION')
DOUBLE_SIDED = SymbolicConstant('DOUBLE_SIDED')
DPI_1200 = SymbolicConstant('DPI_1200')
DPI_150 = SymbolicConstant('DPI_150')
DPI_300 = SymbolicConstant('DPI_300')
DPI_450 = SymbolicConstant('DPI_450')
DPI_600 = SymbolicConstant('DPI_600')
DPI_75 = SymbolicConstant('DPI_75')
DRAG2D = SymbolicConstant('DRAG2D')
DRAG3D = SymbolicConstant('DRAG3D')
DS3 = SymbolicConstant('DS3')
DS4 = SymbolicConstant('DS4')
DS6 = SymbolicConstant('DS6')
DS8 = SymbolicConstant('DS8')
DSAX1 = SymbolicConstant('DSAX1')
DSAX2 = SymbolicConstant('DSAX2')
DSC = SymbolicConstant('DSC')
DUPLICATE_NODES = SymbolicConstant('DUPLICATE_NODES')
DURING_ANALYSIS = SymbolicConstant('DURING_ANALYSIS')
DYNAMIC = SymbolicConstant('DYNAMIC')
DYNAMIC_EXPLICIT = SymbolicConstant('DYNAMIC_EXPLICIT')
DYNAMIC_IMPLICIT = SymbolicConstant('DYNAMIC_IMPLICIT')
DYNAMIC_SUBSPACE = SymbolicConstant('DYNAMIC_SUBSPACE')
DYNAMIC_TEMP_DISPLACEMENT = SymbolicConstant('DYNAMIC_TEMP_DISPLACEMENT')
EC3D8R = SymbolicConstant('EC3D8R')
EC3D8RT = SymbolicConstant('EC3D8RT')
ECURRENT_AREA_TIME = SymbolicConstant('ECURRENT_AREA_TIME')
EDGE = SymbolicConstant('EDGE')
EDGE1 = SymbolicConstant('EDGE1')
EDGE2 = SymbolicConstant('EDGE2')
EDGE3 = SymbolicConstant('EDGE3')
EDGE4 = SymbolicConstant('EDGE4')
EDGES = SymbolicConstant('EDGES')
EDGETOEDGE = SymbolicConstant('EDGETOEDGE')
EDGETOFACE = SymbolicConstant('EDGETOFACE')
EDGE_LIST = SymbolicConstant('EDGE_LIST')
EDGE_SEEDING_METHOD = SymbolicConstant('EDGE_SEEDING_METHOD')
EIGENFREQUENCY = SymbolicConstant('EIGENFREQUENCY')
EIGENVALUE_BUCKLING = SymbolicConstant('EIGENVALUE_BUCKLING')
EITHER = SymbolicConstant('EITHER')
ELASTIC = SymbolicConstant('ELASTIC')
ELASTIC_PLASTIC = SymbolicConstant('ELASTIC_PLASTIC')
ELBOW31 = SymbolicConstant('ELBOW31')
ELBOW31B = SymbolicConstant('ELBOW31B')
ELBOW31C = SymbolicConstant('ELBOW31C')
ELBOW32 = SymbolicConstant('ELBOW32')
ELBOW_MPC = SymbolicConstant('ELBOW_MPC')
ELECTRICAL = SymbolicConstant('ELECTRICAL')
ELECTRICAL_CONTACT = SymbolicConstant('ELECTRICAL_CONTACT')
ELECTRICAL_POTENTIAL_FIELD = SymbolicConstant('ELECTRICAL_POTENTIAL_FIELD')
ELECTRIC_CHARGE = SymbolicConstant('ELECTRIC_CHARGE')
ELECTRIC_CURRENT = SymbolicConstant('ELECTRIC_CURRENT')
ELECTRIC_CURRENT_AREA = SymbolicConstant('ELECTRIC_CURRENT_AREA')
ELECTRIC_POTENTIAL = SymbolicConstant('ELECTRIC_POTENTIAL')
ELECTROMAGNETIC_TIME_HARMONIC = SymbolicConstant('ELECTROMAGNETIC_TIME_HARMONIC')
ELEMENT = SymbolicConstant('ELEMENT')
ELEMENTS = SymbolicConstant('ELEMENTS')
ELEMENT_ALL = SymbolicConstant('ELEMENT_ALL')
ELEMENT_BY_ELEMENT_INCREMENTATION = SymbolicConstant('ELEMENT_BY_ELEMENT_INCREMENTATION')
ELEMENT_CENTER_PROJECTION = SymbolicConstant('ELEMENT_CENTER_PROJECTION')
ELEMENT_CENTROID = SymbolicConstant('ELEMENT_CENTROID')
ELEMENT_FACE = SymbolicConstant('ELEMENT_FACE')
ELEMENT_FACE_INTEGRATION_POINT = SymbolicConstant('ELEMENT_FACE_INTEGRATION_POINT')
ELEMENT_NODAL = SymbolicConstant('ELEMENT_NODAL')
ELEMENT_NODES = SymbolicConstant('ELEMENT_NODES')
ELEMENT_PRESELECT = SymbolicConstant('ELEMENT_PRESELECT')
ELEMENT_SET = SymbolicConstant('ELEMENT_SET')
ELEM_SHAPE = SymbolicConstant('ELEM_SHAPE')
ELLIPSE = SymbolicConstant('ELLIPSE')
ELLIPTICAL = SymbolicConstant('ELLIPTICAL')
ELSET_MAP = SymbolicConstant('ELSET_MAP')
ELSET_MAP_COLORS = SymbolicConstant('ELSET_MAP_COLORS')
ELTYPE_MAP = SymbolicConstant('ELTYPE_MAP')
ELTYPE_MAP_COLORS = SymbolicConstant('ELTYPE_MAP_COLORS')
EMAG = SymbolicConstant('EMAG')
EMBEDDED_COEFF = SymbolicConstant('EMBEDDED_COEFF')
EMBEDDED_ELEMENT = SymbolicConstant('EMBEDDED_ELEMENT')
EMC2D3 = SymbolicConstant('EMC2D3')
EMC2D4 = SymbolicConstant('EMC2D4')
EMC3D4 = SymbolicConstant('EMC3D4')
EMC3D6 = SymbolicConstant('EMC3D6')
EMC3D8 = SymbolicConstant('EMC3D8')
EMF = SymbolicConstant('EMF')
EMPTY_FIELD = SymbolicConstant('EMPTY_FIELD')
EMPTY_LEAF = SymbolicConstant('EMPTY_LEAF')
ENABLED = SymbolicConstant('ENABLED')
ENCASTRE = SymbolicConstant('ENCASTRE')
END = SymbolicConstant('END')
END1 = SymbolicConstant('END1')
END2 = SymbolicConstant('END2')
END3 = SymbolicConstant('END3')
END_FRAME_TIME = SymbolicConstant('END_FRAME_TIME')
END_RELEASE = SymbolicConstant('END_RELEASE')
END_STEP = SymbolicConstant('END_STEP')
ENERGY = SymbolicConstant('ENERGY')
ENERGY_ALL = SymbolicConstant('ENERGY_ALL')
ENERGY_DENSITY = SymbolicConstant('ENERGY_DENSITY')
ENERGY_NONE = SymbolicConstant('ENERGY_NONE')
ENERGY_PRESELECT = SymbolicConstant('ENERGY_PRESELECT')
ENERGY_RELEASE_RATE = SymbolicConstant('ENERGY_RELEASE_RATE')
ENERGY_TYPE = SymbolicConstant('ENERGY_TYPE')
ENFORCEMENT_OFF = SymbolicConstant('ENFORCEMENT_OFF')
ENFORCEMENT_ON = SymbolicConstant('ENFORCEMENT_ON')
ENGINEERING = SymbolicConstant('ENGINEERING')
ENGINEERING_CONSTANTS = SymbolicConstant('ENGINEERING_CONSTANTS')
ENHANCED = SymbolicConstant('ENHANCED')
ENHANCED_VCCT = SymbolicConstant('ENHANCED_VCCT')
ENTEREDCOORD = SymbolicConstant('ENTEREDCOORD')
ENUMERATION = SymbolicConstant('ENUMERATION')
ENVELOPE = SymbolicConstant('ENVELOPE')
EPOTENTIAL_GRADIENT = SymbolicConstant('EPOTENTIAL_GRADIENT')
EPS = SymbolicConstant('EPS')
EQUAL = SymbolicConstant('EQUAL')
EQUALRADIUS = SymbolicConstant('EQUALRADIUS')
EQUATION = SymbolicConstant('EQUATION')
EQUILIBRIUM = SymbolicConstant('EQUILIBRIUM')
EQUIV_STRESS = SymbolicConstant('EQUIV_STRESS')
ERROR = SymbolicConstant('ERROR')
ETOTAL_XPL = SymbolicConstant('ETOTAL_XPL')
EULER = SymbolicConstant('EULER')
EULERIAN = SymbolicConstant('EULERIAN')
EVENT_ACCELERATION = SymbolicConstant('EVENT_ACCELERATION')
EVENT_DISPLACEMENT = SymbolicConstant('EVENT_DISPLACEMENT')
EVENT_GRAVITY = SymbolicConstant('EVENT_GRAVITY')
EVENT_VELOCITY = SymbolicConstant('EVENT_VELOCITY')
EVERY_CYCLE = SymbolicConstant('EVERY_CYCLE')
EVERY_NCYCLES = SymbolicConstant('EVERY_NCYCLES')
EVERY_TIME_INCREMENT = SymbolicConstant('EVERY_TIME_INCREMENT')
EXACT = SymbolicConstant('EXACT')
EXACT_TARGETS = SymbolicConstant('EXACT_TARGETS')
EXCESSIVE_DISTORTION = SymbolicConstant('EXCESSIVE_DISTORTION')
EXCESSIVE_ELEMENT_DISTORTION = SymbolicConstant('EXCESSIVE_ELEMENT_DISTORTION')
EXCESSIVE_STRAIN_INCREMENT = SymbolicConstant('EXCESSIVE_STRAIN_INCREMENT')
EXCLUDE = SymbolicConstant('EXCLUDE')
EXPLICIT = SymbolicConstant('EXPLICIT')
EXPLICIT_ANALYSIS = SymbolicConstant('EXPLICIT_ANALYSIS')
EXPLICIT_DYNAMIC = SymbolicConstant('EXPLICIT_DYNAMIC')
EXPLICIT_ONLY = SymbolicConstant('EXPLICIT_ONLY')
EXPLICIT_PHASE = SymbolicConstant('EXPLICIT_PHASE')
EXPONENTIAL = SymbolicConstant('EXPONENTIAL')
EXPONENTIAL_DECAY = SymbolicConstant('EXPONENTIAL_DECAY')
EXPONENTIAL_LAW = SymbolicConstant('EXPONENTIAL_LAW')
EXPORT_STEP_SIZE = SymbolicConstant('EXPORT_STEP_SIZE')
EXTERIOR = SymbolicConstant('EXTERIOR')
EXTERNAL = SymbolicConstant('EXTERNAL')
EXTRAPOLATE_AVERAGE_COMPUTE = SymbolicConstant('EXTRAPOLATE_AVERAGE_COMPUTE')
EXTRAPOLATE_COMPUTE = SymbolicConstant('EXTRAPOLATE_COMPUTE')
EXTRAPOLATE_COMPUTE_AVERAGE = SymbolicConstant('EXTRAPOLATE_COMPUTE_AVERAGE')
EXTRAPOLATE_COMPUTE_DISCONTINUITIES = SymbolicConstant('EXTRAPOLATE_COMPUTE_DISCONTINUITIES')
EXTRA_COARSE = SymbolicConstant('EXTRA_COARSE')
EXTRA_FINE = SymbolicConstant('EXTRA_FINE')
F2D2 = SymbolicConstant('F2D2')
F3D3 = SymbolicConstant('F3D3')
F3D4 = SymbolicConstant('F3D4')
FACE1 = SymbolicConstant('FACE1')
FACE2 = SymbolicConstant('FACE2')
FACE3 = SymbolicConstant('FACE3')
FACE4 = SymbolicConstant('FACE4')
FACE5 = SymbolicConstant('FACE5')
FACE6 = SymbolicConstant('FACE6')
FACETOEDGE = SymbolicConstant('FACETOEDGE')
FACETOFACE = SymbolicConstant('FACETOFACE')
FACETS = SymbolicConstant('FACETS')
FACE_CENTERED = SymbolicConstant('FACE_CENTERED')
FACE_UNKNOWN = SymbolicConstant('FACE_UNKNOWN')
FACTOR = SymbolicConstant('FACTOR')
FARTHEST_POINT_FRACTION = SymbolicConstant('FARTHEST_POINT_FRACTION')
FAST = SymbolicConstant('FAST')
FASTENER = SymbolicConstant('FASTENER')
FATIGUE = SymbolicConstant('FATIGUE')
FAX2 = SymbolicConstant('FAX2')
FC3D4 = SymbolicConstant('FC3D4')
FC3D5 = SymbolicConstant('FC3D5')
FC3D6 = SymbolicConstant('FC3D6')
FC3D8 = SymbolicConstant('FC3D8')
FEATURE = SymbolicConstant('FEATURE')
FE_SAFE = SymbolicConstant('FE_SAFE')
FGMRES = SymbolicConstant('FGMRES')
FICK = SymbolicConstant('FICK')
FIELD = SymbolicConstant('FIELD')
FIELDREPORTFORMAT = SymbolicConstant('FIELDREPORTFORMAT')
FIELD_OUTPUT = SymbolicConstant('FIELD_OUTPUT')
FIELD_THICKNESS = SymbolicConstant('FIELD_THICKNESS')
FILE = SymbolicConstant('FILE')
FILL = SymbolicConstant('FILL')
FILLED = SymbolicConstant('FILLED')
FILLED_ARROW = SymbolicConstant('FILLED_ARROW')
FILLED_CIRCLE = SymbolicConstant('FILLED_CIRCLE')
FILLED_DIAMOND = SymbolicConstant('FILLED_DIAMOND')
FILLED_SQUARE = SymbolicConstant('FILLED_SQUARE')
FILLED_TRI = SymbolicConstant('FILLED_TRI')
FILTER = SymbolicConstant('FILTER')
FINE = SymbolicConstant('FINE')
FINER = SymbolicConstant('FINER')
FINITE = SymbolicConstant('FINITE')
FIRST = SymbolicConstant('FIRST')
FIRST_AND_LAST = SymbolicConstant('FIRST_AND_LAST')
FIRST_CYCLE = SymbolicConstant('FIRST_CYCLE')
FIRST_FRAME = SymbolicConstant('FIRST_FRAME')
FIRST_ORDER_ADVECTION = SymbolicConstant('FIRST_ORDER_ADVECTION')
FIRST_STEP = SymbolicConstant('FIRST_STEP')
FITTED_VALUE = SymbolicConstant('FITTED_VALUE')
FIT_HEIGHT = SymbolicConstant('FIT_HEIGHT')
FIT_TO_PAGE = SymbolicConstant('FIT_TO_PAGE')
FIT_TO_VIEWPORT = SymbolicConstant('FIT_TO_VIEWPORT')
FIT_WIDTH = SymbolicConstant('FIT_WIDTH')
FIXED = SymbolicConstant('FIXED')
FIXED_CFL = SymbolicConstant('FIXED_CFL')
FIXED_DOF = SymbolicConstant('FIXED_DOF')
FIXED_EBE = SymbolicConstant('FIXED_EBE')
FIXED_INCREMENTATION = SymbolicConstant('FIXED_INCREMENTATION')
FIXED_TIME = SymbolicConstant('FIXED_TIME')
FIXED_USER_DEFINED_INC = SymbolicConstant('FIXED_USER_DEFINED_INC')
FIX_LENGTH = SymbolicConstant('FIX_LENGTH')
FIX_NONE = SymbolicConstant('FIX_NONE')
FLD = SymbolicConstant('FLD')
FLEXIBLE = SymbolicConstant('FLEXIBLE')
FLEXION_TORSION = SymbolicConstant('FLEXION_TORSION')
FLINK = SymbolicConstant('FLINK')
FLOAT = SymbolicConstant('FLOAT')
FLOW = SymbolicConstant('FLOW')
FLOW_CONVERTER = SymbolicConstant('FLOW_CONVERTER')
FLUID = SymbolicConstant('FLUID')
FLUID_PRESSURE_FIELD = SymbolicConstant('FLUID_PRESSURE_FIELD')
FOLLOW = SymbolicConstant('FOLLOW')
FONT = SymbolicConstant('FONT')
FORCE = SymbolicConstant('FORCE')
FORCE_SINGLE = SymbolicConstant('FORCE_SINGLE')
FORCE_VOLUME = SymbolicConstant('FORCE_VOLUME')
FORMULA = SymbolicConstant('FORMULA')
FORWARD = SymbolicConstant('FORWARD')
FRACTION = SymbolicConstant('FRACTION')
FRACTIONAL = SymbolicConstant('FRACTIONAL')
FRACTURE_MECHANICS = SymbolicConstant('FRACTURE_MECHANICS')
FRAME2D = SymbolicConstant('FRAME2D')
FRAME3D = SymbolicConstant('FRAME3D')
FRAME_BASED = SymbolicConstant('FRAME_BASED')
FRAME_VALUE = SymbolicConstant('FRAME_VALUE')
FREE = SymbolicConstant('FREE')
FREED = SymbolicConstant('FREED')
FREE_FORM = SymbolicConstant('FREE_FORM')
FREE_TASK_REGION_EQUIV_STRESS = SymbolicConstant('FREE_TASK_REGION_EQUIV_STRESS')
FREQUENCY = SymbolicConstant('FREQUENCY')
FREQUENCY_DATA = SymbolicConstant('FREQUENCY_DATA')
FREQUENCY_RANGE = SymbolicConstant('FREQUENCY_RANGE')
FRICTIONLESS = SymbolicConstant('FRICTIONLESS')
FROM_ASCII_FILE = SymbolicConstant('FROM_ASCII_FILE')
FROM_FILE = SymbolicConstant('FROM_FILE')
FROM_FILE_AND_USER_DEFINED = SymbolicConstant('FROM_FILE_AND_USER_DEFINED')
FROM_GEOMETRY = SymbolicConstant('FROM_GEOMETRY')
FROM_KEYBOARD = SymbolicConstant('FROM_KEYBOARD')
FROM_ODB = SymbolicConstant('FROM_ODB')
FROM_OPERATION = SymbolicConstant('FROM_OPERATION')
FROM_SECTION = SymbolicConstant('FROM_SECTION')
FROM_USER_DEFINED = SymbolicConstant('FROM_USER_DEFINED')
FULL = SymbolicConstant('FULL')
FULLY = SymbolicConstant('FULLY')
FULL_CYCLE = SymbolicConstant('FULL_CYCLE')
FULL_FIELD = SymbolicConstant('FULL_FIELD')
FULL_NEWTON = SymbolicConstant('FULL_NEWTON')
FUNG_ANISOTROPIC = SymbolicConstant('FUNG_ANISOTROPIC')
FUNG_ORTHOTROPIC = SymbolicConstant('FUNG_ORTHOTROPIC')
G = SymbolicConstant('G')
GALERKIN = SymbolicConstant('GALERKIN')
GAPCYL = SymbolicConstant('GAPCYL')
GAPSPHER = SymbolicConstant('GAPSPHER')
GAPUNI = SymbolicConstant('GAPUNI')
GAPUNIT = SymbolicConstant('GAPUNIT')
GASKET = SymbolicConstant('GASKET')
GAUSS = SymbolicConstant('GAUSS')
GAUSS_COUPLING = SymbolicConstant('GAUSS_COUPLING')
GENERAL = SymbolicConstant('GENERAL')
GENERALIZED = SymbolicConstant('GENERALIZED')
GENERALIZED_BEAM = SymbolicConstant('GENERALIZED_BEAM')
GENERALIZED_DECAY = SymbolicConstant('GENERALIZED_DECAY')
GENERALIZED_SHELL = SymbolicConstant('GENERALIZED_SHELL')
GENERAL_OPTIMIZATION = SymbolicConstant('GENERAL_OPTIMIZATION')
GENERAL_PARTICLE = SymbolicConstant('GENERAL_PARTICLE')
GEOMETRY = SymbolicConstant('GEOMETRY')
GEOMETRYFORMAT = SymbolicConstant('GEOMETRYFORMAT')
GEOMETRY_ENHANCED = SymbolicConstant('GEOMETRY_ENHANCED')
GEOM_DEVIATION_FACTOR = SymbolicConstant('GEOM_DEVIATION_FACTOR')
GEOSTATIC = SymbolicConstant('GEOSTATIC')
GFI = SymbolicConstant('GFI')
GIGA_BYTES = SymbolicConstant('GIGA_BYTES')
GK2D2 = SymbolicConstant('GK2D2')
GK2D2N = SymbolicConstant('GK2D2N')
GK3D12M = SymbolicConstant('GK3D12M')
GK3D12MN = SymbolicConstant('GK3D12MN')
GK3D18 = SymbolicConstant('GK3D18')
GK3D18N = SymbolicConstant('GK3D18N')
GK3D2 = SymbolicConstant('GK3D2')
GK3D2N = SymbolicConstant('GK3D2N')
GK3D4L = SymbolicConstant('GK3D4L')
GK3D4LN = SymbolicConstant('GK3D4LN')
GK3D6 = SymbolicConstant('GK3D6')
GK3D6L = SymbolicConstant('GK3D6L')
GK3D6LN = SymbolicConstant('GK3D6LN')
GK3D6N = SymbolicConstant('GK3D6N')
GK3D8 = SymbolicConstant('GK3D8')
GK3D8N = SymbolicConstant('GK3D8N')
GKAX2 = SymbolicConstant('GKAX2')
GKAX2N = SymbolicConstant('GKAX2N')
GKAX4 = SymbolicConstant('GKAX4')
GKAX4N = SymbolicConstant('GKAX4N')
GKAX6 = SymbolicConstant('GKAX6')
GKAX6N = SymbolicConstant('GKAX6N')
GKPE4 = SymbolicConstant('GKPE4')
GKPE6 = SymbolicConstant('GKPE6')
GKPS4 = SymbolicConstant('GKPS4')
GKPS4N = SymbolicConstant('GKPS4N')
GKPS6 = SymbolicConstant('GKPS6')
GKPS6N = SymbolicConstant('GKPS6N')
GLOBAL = SymbolicConstant('GLOBAL')
GLOBAL_NONE = SymbolicConstant('GLOBAL_NONE')
GLOBAL_X = SymbolicConstant('GLOBAL_X')
GLOBAL_Y = SymbolicConstant('GLOBAL_Y')
GLOBAL_Z = SymbolicConstant('GLOBAL_Z')
GOURAUD = SymbolicConstant('GOURAUD')
GRADED = SymbolicConstant('GRADED')
GRADIENT = SymbolicConstant('GRADIENT')
GRADIENTS = SymbolicConstant('GRADIENTS')
GRADIENTS_THROUGH_BEAM_CS = SymbolicConstant('GRADIENTS_THROUGH_BEAM_CS')
GRADIENTS_THROUGH_SHELL_CS = SymbolicConstant('GRADIENTS_THROUGH_SHELL_CS')
GRAVITY = SymbolicConstant('GRAVITY')
GREATER_THAN = SymbolicConstant('GREATER_THAN')
GREATER_THAN_EQUAL = SymbolicConstant('GREATER_THAN_EQUAL')
GREYSCALE = SymbolicConstant('GREYSCALE')
GRID = SymbolicConstant('GRID')
GROUND = SymbolicConstant('GROUND')
GROUP_BY_MATERIAL = SymbolicConstant('GROUP_BY_MATERIAL')
GROWTH_MOVEMENT = SymbolicConstant('GROWTH_MOVEMENT')
GRP = SymbolicConstant('GRP')
HALF = SymbolicConstant('HALF')
HALF_CYCLE = SymbolicConstant('HALF_CYCLE')
HALF_INDEX_SHIFT = SymbolicConstant('HALF_INDEX_SHIFT')
HALF_OF_AVERAGE = SymbolicConstant('HALF_OF_AVERAGE')
HARD = SymbolicConstant('HARD')
HARDWARE_OVERLAY = SymbolicConstant('HARDWARE_OVERLAY')
HARMONIC = SymbolicConstant('HARMONIC')
HEADING = SymbolicConstant('HEADING')
HEALER_TYPE = SymbolicConstant('HEALER_TYPE')
HEATCAP = SymbolicConstant('HEATCAP')
HEAT_FLUX = SymbolicConstant('HEAT_FLUX')
HEAT_FLUX_AREA = SymbolicConstant('HEAT_FLUX_AREA')
HEAT_FLUX_RATE = SymbolicConstant('HEAT_FLUX_RATE')
HEAT_FLUX_VOLUME = SymbolicConstant('HEAT_FLUX_VOLUME')
HEAT_TRANSFER = SymbolicConstant('HEAT_TRANSFER')
HEIGHT = SymbolicConstant('HEIGHT')
HEX = SymbolicConstant('HEX')
HEX20 = SymbolicConstant('HEX20')
HEX8 = SymbolicConstant('HEX8')
HEX_DOMINATED = SymbolicConstant('HEX_DOMINATED')
HIDDEN = SymbolicConstant('HIDDEN')
HIGH = SymbolicConstant('HIGH')
HINGE = SymbolicConstant('HINGE')
HISTORY = SymbolicConstant('HISTORY')
HOLLOW_CIRCLE = SymbolicConstant('HOLLOW_CIRCLE')
HOLLOW_DIAMOND = SymbolicConstant('HOLLOW_DIAMOND')
HOLLOW_SQUARE = SymbolicConstant('HOLLOW_SQUARE')
HOLLOW_TRI = SymbolicConstant('HOLLOW_TRI')
HOLZAPFEL = SymbolicConstant('HOLZAPFEL')
HOME = SymbolicConstant('HOME')
HORIZONTAL = SymbolicConstant('HORIZONTAL')
HYBRID = SymbolicConstant('HYBRID')
HYDRAULIC = SymbolicConstant('HYDRAULIC')
HYDROSTATIC = SymbolicConstant('HYDROSTATIC')
HYDROSTATIC_FLUID_MODELING = SymbolicConstant('HYDROSTATIC_FLUID_MODELING')
HYPERBOLIC = SymbolicConstant('HYPERBOLIC')
HYPERBOLIC_SINE = SymbolicConstant('HYPERBOLIC_SINE')
HYSTERESIS_INITIAL_GUESSES_EXHAUSTED = SymbolicConstant('HYSTERESIS_INITIAL_GUESSES_EXHAUSTED')
HYSTERESIS_JACOBIAN_CANNOT_BE_INVERTED = SymbolicConstant('HYSTERESIS_JACOBIAN_CANNOT_BE_INVERTED')
ICC = SymbolicConstant('ICC')
IDEALGAS = SymbolicConstant('IDEALGAS')
IDENTICAL = SymbolicConstant('IDENTICAL')
IDENTITY = SymbolicConstant('IDENTITY')
IGNITIONANDGROWTH = SymbolicConstant('IGNITIONANDGROWTH')
IMAGINARY = SymbolicConstant('IMAGINARY')
IMMEDIATE = SymbolicConstant('IMMEDIATE')
IMPEDANCE = SymbolicConstant('IMPEDANCE')
IMPERFECTION = SymbolicConstant('IMPERFECTION')
IMPLICIT = SymbolicConstant('IMPLICIT')
IMPLICIT_DYNAMIC = SymbolicConstant('IMPLICIT_DYNAMIC')
IMPLICIT_EXPLICIT = SymbolicConstant('IMPLICIT_EXPLICIT')
IMPORT = SymbolicConstant('IMPORT')
IMPORT_STEP_SIZE = SymbolicConstant('IMPORT_STEP_SIZE')
IMPRINT = SymbolicConstant('IMPRINT')
IMPROVED = SymbolicConstant('IMPROVED')
INCHES = SymbolicConstant('INCHES')
INCLUDE = SymbolicConstant('INCLUDE')
INCOMPRESSIBLE = SymbolicConstant('INCOMPRESSIBLE')
INCREMENT = SymbolicConstant('INCREMENT')
INCREMENTAL = SymbolicConstant('INCREMENTAL')
INCREMENTATION = SymbolicConstant('INCREMENTATION')
INCREMENTATION_ALL = SymbolicConstant('INCREMENTATION_ALL')
INCREMENTATION_PRESELECT = SymbolicConstant('INCREMENTATION_PRESELECT')
INC_SIZE = SymbolicConstant('INC_SIZE')
INDEPENDENT = SymbolicConstant('INDEPENDENT')
INDEX = SymbolicConstant('INDEX')
INERTIA_RELIEF = SymbolicConstant('INERTIA_RELIEF')
INFILTRATION = SymbolicConstant('INFILTRATION')
INFINITE = SymbolicConstant('INFINITE')
INFLOW = SymbolicConstant('INFLOW')
INITIAL = SymbolicConstant('INITIAL')
INITIAL_AND_LAST = SymbolicConstant('INITIAL_AND_LAST')
INITIAL_CONDITION = SymbolicConstant('INITIAL_CONDITION')
INITIAL_NODES = SymbolicConstant('INITIAL_NODES')
INITIAL_OPENINGS = SymbolicConstant('INITIAL_OPENINGS')
INITIAL_OVERCLOSURES = SymbolicConstant('INITIAL_OVERCLOSURES')
INITIAL_OVERCLOSURES_EXPLICIT = SymbolicConstant('INITIAL_OVERCLOSURES_EXPLICIT')
INPUT = SymbolicConstant('INPUT')
INPUT_FILE = SymbolicConstant('INPUT_FILE')
INSIDE = SymbolicConstant('INSIDE')
INSTANCE = SymbolicConstant('INSTANCE')
INSTANCE_FROM_INSTANCE = SymbolicConstant('INSTANCE_FROM_INSTANCE')
INSTANCE_FROM_PART = SymbolicConstant('INSTANCE_FROM_PART')
INSTANCE_MAP = SymbolicConstant('INSTANCE_MAP')
INSTANCE_MAP_COLORS = SymbolicConstant('INSTANCE_MAP_COLORS')
INSTANCE_NOT_APPLICABLE = SymbolicConstant('INSTANCE_NOT_APPLICABLE')
INSTANCE_TYPE_MAP = SymbolicConstant('INSTANCE_TYPE_MAP')
INSTANCE_TYPE_MAP_COLORS = SymbolicConstant('INSTANCE_TYPE_MAP_COLORS')
INSTANTANEOUS = SymbolicConstant('INSTANTANEOUS')
INTEGER = SymbolicConstant('INTEGER')
INTEGRATED_ALL = SymbolicConstant('INTEGRATED_ALL')
INTEGRATED_PRESELECT = SymbolicConstant('INTEGRATED_PRESELECT')
INTEGRATION_POINT = SymbolicConstant('INTEGRATION_POINT')
INTEGRATION_POINTS = SymbolicConstant('INTEGRATION_POINTS')
INTERACTION_MAP = SymbolicConstant('INTERACTION_MAP')
INTERACTION_MAP_COLORS = SymbolicConstant('INTERACTION_MAP_COLORS')
INTERACTION_PROP_MAP = SymbolicConstant('INTERACTION_PROP_MAP')
INTERACTION_PROP_MAP_COLORS = SymbolicConstant('INTERACTION_PROP_MAP_COLORS')
INTERACTION_TYPE_MAP = SymbolicConstant('INTERACTION_TYPE_MAP')
INTERACTION_TYPE_MAP_COLORS = SymbolicConstant('INTERACTION_TYPE_MAP_COLORS')
INTERFERENCE = SymbolicConstant('INTERFERENCE')
INTERNAL = SymbolicConstant('INTERNAL')
INTERNAL_SET_MAP = SymbolicConstant('INTERNAL_SET_MAP')
INTERNAL_SET_MAP_COLORS = SymbolicConstant('INTERNAL_SET_MAP_COLORS')
INTERNAL_SURFACE_MAP = SymbolicConstant('INTERNAL_SURFACE_MAP')
INTERNAL_SURFACE_MAP_COLORS = SymbolicConstant('INTERNAL_SURFACE_MAP_COLORS')
INTERPOLATED = SymbolicConstant('INTERPOLATED')
INTERPOLATE_OFF = SymbolicConstant('INTERPOLATE_OFF')
INTERPOLATE_ON = SymbolicConstant('INTERPOLATE_ON')
INTERRUPTED = SymbolicConstant('INTERRUPTED')
INTERSECTION = SymbolicConstant('INTERSECTION')
INTERSECTIONS = SymbolicConstant('INTERSECTIONS')
INV3 = SymbolicConstant('INV3')
INVALID = SymbolicConstant('INVALID')
INVALID_SURF = SymbolicConstant('INVALID_SURF')
INVARIANT = SymbolicConstant('INVARIANT')
INWARD = SymbolicConstant('INWARD')
ISL21A = SymbolicConstant('ISL21A')
ISL22A = SymbolicConstant('ISL22A')
ISOLINES = SymbolicConstant('ISOLINES')
ISOSURFACE = SymbolicConstant('ISOSURFACE')
ISOTROPIC = SymbolicConstant('ISOTROPIC')
ISOTROPIC_CFD = SymbolicConstant('ISOTROPIC_CFD')
ITERATION = SymbolicConstant('ITERATION')
ITERATIVE = SymbolicConstant('ITERATIVE')
ITERATIVE_SOLVER = SymbolicConstant('ITERATIVE_SOLVER')
ITSCYL = SymbolicConstant('ITSCYL')
ITSUNI = SymbolicConstant('ITSUNI')
ITT21 = SymbolicConstant('ITT21')
ITT31 = SymbolicConstant('ITT31')
JACOBI_COUPLING = SymbolicConstant('JACOBI_COUPLING')
JAMA = SymbolicConstant('JAMA')
JOB_ABORTED = SymbolicConstant('JOB_ABORTED')
JOB_COMPLETED = SymbolicConstant('JOB_COMPLETED')
JOB_INTERRUPTED = SymbolicConstant('JOB_INTERRUPTED')
JOB_STATUS_COMPLETED_SUCCESSFULLY = SymbolicConstant('JOB_STATUS_COMPLETED_SUCCESSFULLY')
JOB_STATUS_EXITED_WITH_ERROR = SymbolicConstant('JOB_STATUS_EXITED_WITH_ERROR')
JOB_STATUS_TERMINATED_BY_EXTERNAL_REQUEST = SymbolicConstant('JOB_STATUS_TERMINATED_BY_EXTERNAL_REQUEST')
JOB_STATUS_UNKNOWN = SymbolicConstant('JOB_STATUS_UNKNOWN')
JOB_SUBMITTED = SymbolicConstant('JOB_SUBMITTED')
JOHNSON_COOK = SymbolicConstant('JOHNSON_COOK')
JOIN = SymbolicConstant('JOIN')
JOINT2D = SymbolicConstant('JOINT2D')
JOINT3D = SymbolicConstant('JOINT3D')
JOINTC = SymbolicConstant('JOINTC')
JUSTIFY_LEFT = SymbolicConstant('JUSTIFY_LEFT')
JWL = SymbolicConstant('JWL')
J_INTEGRAL = SymbolicConstant('J_INTEGRAL')
KEPS_RNG = SymbolicConstant('KEPS_RNG')
KII0 = SymbolicConstant('KII0')
KINEMATIC = SymbolicConstant('KINEMATIC')
KINEMATIC_COUPLING = SymbolicConstant('KINEMATIC_COUPLING')
KINEMATIC_HARDENING = SymbolicConstant('KINEMATIC_HARDENING')
KINEMATIC_VIOLATIONS = SymbolicConstant('KINEMATIC_VIOLATIONS')
KINETIC_ENERGY_XPL = SymbolicConstant('KINETIC_ENERGY_XPL')
K_FACTORS = SymbolicConstant('K_FACTORS')
LAGRANGE = SymbolicConstant('LAGRANGE')
LAGRANGIAN = SymbolicConstant('LAGRANGIAN')
LAG_ANALYSIS = SymbolicConstant('LAG_ANALYSIS')
LAMINA = SymbolicConstant('LAMINA')
LANCZOS = SymbolicConstant('LANCZOS')
LANCZOS_EIGENSOLVER = SymbolicConstant('LANCZOS_EIGENSOLVER')
LANDSCAPE = SymbolicConstant('LANDSCAPE')
LARGE = SymbolicConstant('LARGE')
LARGE_ANGLE = SymbolicConstant('LARGE_ANGLE')
LARGE_ANGLE_QUAD_FACE = SymbolicConstant('LARGE_ANGLE_QUAD_FACE')
LARGE_ANGLE_TRI_FACE = SymbolicConstant('LARGE_ANGLE_TRI_FACE')
LARGE_STRAIN_INCREMENT = SymbolicConstant('LARGE_STRAIN_INCREMENT')
LAST = SymbolicConstant('LAST')
LAST_FRAME = SymbolicConstant('LAST_FRAME')
LAST_INCREMENT = SymbolicConstant('LAST_INCREMENT')
LAST_STEP = SymbolicConstant('LAST_STEP')
LATERAL_EXTENSION_RATIO_NOT_FOUND = SymbolicConstant('LATERAL_EXTENSION_RATIO_NOT_FOUND')
LATERAL_NOMINAL_STRAIN = SymbolicConstant('LATERAL_NOMINAL_STRAIN')
LAYUP = SymbolicConstant('LAYUP')
LAYUP_MAP = SymbolicConstant('LAYUP_MAP')
LAYUP_MAP_COLORS = SymbolicConstant('LAYUP_MAP_COLORS')
LAYUP_ORIENTATION = SymbolicConstant('LAYUP_ORIENTATION')
LEAD_ANALYSIS = SymbolicConstant('LEAD_ANALYSIS')
LEAF_COLORS = SymbolicConstant('LEAF_COLORS')
LEDGER = SymbolicConstant('LEDGER')
LEFT = SymbolicConstant('LEFT')
LEGAL = SymbolicConstant('LEGAL')
LENGTH = SymbolicConstant('LENGTH')
LESS_THAN = SymbolicConstant('LESS_THAN')
LESS_THAN_EQUAL = SymbolicConstant('LESS_THAN_EQUAL')
LETTER = SymbolicConstant('LETTER')
LETTERS = SymbolicConstant('LETTERS')
LICENSING = SymbolicConstant('LICENSING')
LIFT_EQUATION = SymbolicConstant('LIFT_EQUATION')
LINE = SymbolicConstant('LINE')
LINE2 = SymbolicConstant('LINE2')
LINE3 = SymbolicConstant('LINE3')
LINEAR = SymbolicConstant('LINEAR')
LINEAR_EXTRAPOLATION = SymbolicConstant('LINEAR_EXTRAPOLATION')
LINEAR_LEAST_SQUARES = SymbolicConstant('LINEAR_LEAST_SQUARES')
LINEAR_PRESSURE = SymbolicConstant('LINEAR_PRESSURE')
LINELINEDIST = SymbolicConstant('LINELINEDIST')
LINES = SymbolicConstant('LINES')
LINE_LOOP = SymbolicConstant('LINE_LOOP')
LINE_SEARCH = SymbolicConstant('LINE_SEARCH')
LINE_STRIP = SymbolicConstant('LINE_STRIP')
LINK = SymbolicConstant('LINK')
LINK_MPC = SymbolicConstant('LINK_MPC')
LINUX = SymbolicConstant('LINUX')
LIST_OF_MODES = SymbolicConstant('LIST_OF_MODES')
LOAD = SymbolicConstant('LOAD')
LOAD_CASE = SymbolicConstant('LOAD_CASE')
LOAD_MAP = SymbolicConstant('LOAD_MAP')
LOAD_MAP_COLORS = SymbolicConstant('LOAD_MAP_COLORS')
LOCAL = SymbolicConstant('LOCAL')
LOCAL_GRADIENT = SymbolicConstant('LOCAL_GRADIENT')
LOCKSTEP = SymbolicConstant('LOCKSTEP')
LOG = SymbolicConstant('LOG')
LOGARITHMIC = SymbolicConstant('LOGARITHMIC')
LONG = SymbolicConstant('LONG')
LONGEST_EDGE = SymbolicConstant('LONGEST_EDGE')
LONG_TERM = SymbolicConstant('LONG_TERM')
LOOP = SymbolicConstant('LOOP')
LOOP_BACKWARD = SymbolicConstant('LOOP_BACKWARD')
LOOSE_COUPLING = SymbolicConstant('LOOSE_COUPLING')
LOW = SymbolicConstant('LOW')
LS3S = SymbolicConstant('LS3S')
LS6 = SymbolicConstant('LS6')
LUMIN = SymbolicConstant('LUMIN')
M3D3 = SymbolicConstant('M3D3')
M3D4 = SymbolicConstant('M3D4')
M3D4R = SymbolicConstant('M3D4R')
M3D6 = SymbolicConstant('M3D6')
M3D8 = SymbolicConstant('M3D8')
M3D8R = SymbolicConstant('M3D8R')
MACAULEY = SymbolicConstant('MACAULEY')
MAGNITUDE = SymbolicConstant('MAGNITUDE')
MAGNITUDE_AND_PHASE = SymbolicConstant('MAGNITUDE_AND_PHASE')
MAINTAIN_CURRENT = SymbolicConstant('MAINTAIN_CURRENT')
MAIN_REGION = SymbolicConstant('MAIN_REGION')
MANUAL = SymbolicConstant('MANUAL')
MAP = SymbolicConstant('MAP')
MARLOW = SymbolicConstant('MARLOW')
MASS = SymbolicConstant('MASS')
MASS_DIFFUSION = SymbolicConstant('MASS_DIFFUSION')
MASS_FLOW_AREA = SymbolicConstant('MASS_FLOW_AREA')
MASS_FLOW_AREA_RATE = SymbolicConstant('MASS_FLOW_AREA_RATE')
MASS_FLOW_RATE = SymbolicConstant('MASS_FLOW_RATE')
MASS_FLUX = SymbolicConstant('MASS_FLUX')
MASS_PER_AREA = SymbolicConstant('MASS_PER_AREA')
MASS_PER_LENGTH = SymbolicConstant('MASS_PER_LENGTH')
MASS_PER_VOLUME = SymbolicConstant('MASS_PER_VOLUME')
MASS_PROPORTIONAL = SymbolicConstant('MASS_PROPORTIONAL')
MASS_RATE_LEAK = SymbolicConstant('MASS_RATE_LEAK')
MASS_SCALING = SymbolicConstant('MASS_SCALING')
MASTER = SymbolicConstant('MASTER')
MATCH = SymbolicConstant('MATCH')
MATERIAL = SymbolicConstant('MATERIAL')
MATERIAL_FLOW_FIELD = SymbolicConstant('MATERIAL_FLOW_FIELD')
MATERIAL_INSTABILITY = SymbolicConstant('MATERIAL_INSTABILITY')
MATERIAL_MAP = SymbolicConstant('MATERIAL_MAP')
MATERIAL_MAP_COLORS = SymbolicConstant('MATERIAL_MAP_COLORS')
MATERIAL_POINT_CALCULATIONS = SymbolicConstant('MATERIAL_POINT_CALCULATIONS')
MATRIX = SymbolicConstant('MATRIX')
MAX = SymbolicConstant('MAX')
MAX1 = SymbolicConstant('MAX1')
MAX2 = SymbolicConstant('MAX2')
MAXIMIZE = SymbolicConstant('MAXIMIZE')
MAXIMIZED = SymbolicConstant('MAXIMIZED')
MAXIMUM = SymbolicConstant('MAXIMUM')
MAXIMUM_NUMBER_OF_CONTACT_STRESS_AUGMENTATIONS = SymbolicConstant('MAXIMUM_NUMBER_OF_CONTACT_STRESS_AUGMENTATIONS')
MAXIMUM_NUMBER_OF_EQUILIBRIUM_ITERATIONS = SymbolicConstant('MAXIMUM_NUMBER_OF_EQUILIBRIUM_ITERATIONS')
MAXIMUM_NUMBER_OF_SEVERE_DISCONTINUITY_ITERATIONS = SymbolicConstant(
    'MAXIMUM_NUMBER_OF_SEVERE_DISCONTINUITY_ITERATIONS')
MAXIMUM_SLIDE_DISTANCE_EXCEEDED = SymbolicConstant('MAXIMUM_SLIDE_DISTANCE_EXCEEDED')
MAX_ABS_VALUE = SymbolicConstant('MAX_ABS_VALUE')
MAX_CORRECTION = SymbolicConstant('MAX_CORRECTION')
MAX_EDGE = SymbolicConstant('MAX_EDGE')
MAX_ERROR = SymbolicConstant('MAX_ERROR')
MAX_ELASTOPLASTIC_STRAIN = SymbolicConstant('MAX_ELASTOPLASTIC_STRAIN')
MAX_FREQUENCY = SymbolicConstant('MAX_FREQUENCY')
MAX_INCREMENT = SymbolicConstant('MAX_INCREMENT')
MAX_INPLANE_PRINCIPAL = SymbolicConstant('MAX_INPLANE_PRINCIPAL')
MAX_PRINCIPAL = SymbolicConstant('MAX_PRINCIPAL')
MAX_RESIDUAL = SymbolicConstant('MAX_RESIDUAL')
MAX_SEPARATION = SymbolicConstant('MAX_SEPARATION')
MAX_SHEAR_STRAIN = SymbolicConstant('MAX_SHEAR_STRAIN')
MAX_STEP_SIZE = SymbolicConstant('MAX_STEP_SIZE')
MAX_STRESS = SymbolicConstant('MAX_STRESS')
MAX_VALUE = SymbolicConstant('MAX_VALUE')
MCL6 = SymbolicConstant('MCL6')
MCL9 = SymbolicConstant('MCL9')
MECHANICAL = SymbolicConstant('MECHANICAL')
MECHANICAL_CONTACT = SymbolicConstant('MECHANICAL_CONTACT')
MEDIAL_AXIS = SymbolicConstant('MEDIAL_AXIS')
MEDIUM = SymbolicConstant('MEDIUM')
MEGA_BYTES = SymbolicConstant('MEGA_BYTES')
MEMBRANE = SymbolicConstant('MEMBRANE')
MEMORY = SymbolicConstant('MEMORY')
MEMORY_ESTIMATE = SymbolicConstant('MEMORY_ESTIMATE')
MERGE = SymbolicConstant('MERGE')
MERR = SymbolicConstant('MERR')
MESH = SymbolicConstant('MESH')
MESHED_BEAM_SECTION = SymbolicConstant('MESHED_BEAM_SECTION')
MESH_MAP = SymbolicConstant('MESH_MAP')
MESH_MAP_COLORS = SymbolicConstant('MESH_MAP_COLORS')
MESH_TIE = SymbolicConstant('MESH_TIE')
MGAX1 = SymbolicConstant('MGAX1')
MGAX2 = SymbolicConstant('MGAX2')
MIDDLE = SymbolicConstant('MIDDLE')
MIDDLE_SURFACE = SymbolicConstant('MIDDLE_SURFACE')
MIDSIDE_ONLY = SymbolicConstant('MIDSIDE_ONLY')
MID_PRINCIPAL = SymbolicConstant('MID_PRINCIPAL')
MILLING_REGION = SymbolicConstant('MILLING_REGION')
MIN = SymbolicConstant('MIN')
MINIMIZE = SymbolicConstant('MINIMIZE')
MINIMIZED = SymbolicConstant('MINIMIZED')
MINIMIZE_MAXIMUM = SymbolicConstant('MINIMIZE_MAXIMUM')
MINIMUM = SymbolicConstant('MINIMUM')
MINIMUM_MAXIMUM = SymbolicConstant('MINIMUM_MAXIMUM')
MINIMUM_MOVE = SymbolicConstant('MINIMUM_MOVE')
MIN_EDGE = SymbolicConstant('MIN_EDGE')
MIN_INPLANE_PRINCIPAL = SymbolicConstant('MIN_INPLANE_PRINCIPAL')
MIN_MAX_EDGE = SymbolicConstant('MIN_MAX_EDGE')
MIN_MAX_LABEL = SymbolicConstant('MIN_MAX_LABEL')
MIN_PRINCIPAL = SymbolicConstant('MIN_PRINCIPAL')
MIN_PRINCIPAL_STRAIN = SymbolicConstant('MIN_PRINCIPAL_STRAIN')
MIN_SIZE_FACTOR = SymbolicConstant('MIN_SIZE_FACTOR')
MIN_STEP_SIZE = SymbolicConstant('MIN_STEP_SIZE')
MIN_TRANSITION = SymbolicConstant('MIN_TRANSITION')
MIN_VALUE = SymbolicConstant('MIN_VALUE')
MIRROR = SymbolicConstant('MIRROR')
MIRROR_CIRC_RECT = SymbolicConstant('MIRROR_CIRC_RECT')
MIRROR_RECT_CIRC = SymbolicConstant('MIRROR_RECT_CIRC')
MISES = SymbolicConstant('MISES')
MIXED = SymbolicConstant('MIXED')
MM = SymbolicConstant('MM')
MODAL = SymbolicConstant('MODAL')
MODAL_ALL = SymbolicConstant('MODAL_ALL')
MODAL_DYNAMICS = SymbolicConstant('MODAL_DYNAMICS')
MODEL = SymbolicConstant('MODEL')
MODEL_CHANGE = SymbolicConstant('MODEL_CHANGE')
MODEL_SIZE = SymbolicConstant('MODEL_SIZE')
MODERATE = SymbolicConstant('MODERATE')
MODERATE_DISSIPATION = SymbolicConstant('MODERATE_DISSIPATION')
MODES = SymbolicConstant('MODES')
MODE_BASED_DYNAMIC = SymbolicConstant('MODE_BASED_DYNAMIC')
MODE_BASED_STEADY_STATE_DYNAMIC = SymbolicConstant('MODE_BASED_STEADY_STATE_DYNAMIC')
MODE_INDEPENDENT = SymbolicConstant('MODE_INDEPENDENT')
MODE_NUMBER = SymbolicConstant('MODE_NUMBER')
MODE_RANGE = SymbolicConstant('MODE_RANGE')
MODIFIED = SymbolicConstant('MODIFIED')
MODIFIED_FROM_BASE_STATE = SymbolicConstant('MODIFIED_FROM_BASE_STATE')
MOMENT = SymbolicConstant('MOMENT')
MONITOR_DATA = SymbolicConstant('MONITOR_DATA')
MOONEY_RIVLIN = SymbolicConstant('MOONEY_RIVLIN')
MOTION = SymbolicConstant('MOTION')
MOTION_TYPE = SymbolicConstant('MOTION_TYPE')
MOVEMENT = SymbolicConstant('MOVEMENT')
MOVING_NOISE = SymbolicConstant('MOVING_NOISE')
MPC = SymbolicConstant('MPC')
MPI = SymbolicConstant('MPI')
MSBO = SymbolicConstant('MSBO')
MSFLD = SymbolicConstant('MSFLD')
MSPEI_XPL = SymbolicConstant('MSPEI_XPL')
MT = SymbolicConstant('MT')
MTS = SymbolicConstant('MTS')
MULTIPLE_DIRECTION_ABSOLUTE_SUM = SymbolicConstant('MULTIPLE_DIRECTION_ABSOLUTE_SUM')
MULTIPLE_DIRECTION_FORTY_PERCENT_RULE = SymbolicConstant('MULTIPLE_DIRECTION_FORTY_PERCENT_RULE')
MULTIPLE_DIRECTION_SRSS_SUM = SymbolicConstant('MULTIPLE_DIRECTION_SRSS_SUM')
MULTIPLE_DIRECTION_THIRTY_PERCENT_RULE = SymbolicConstant('MULTIPLE_DIRECTION_THIRTY_PERCENT_RULE')
MULTIPLE_SURFACE = SymbolicConstant('MULTIPLE_SURFACE')
MULTIPLICATIVE = SymbolicConstant('MULTIPLICATIVE')
MULTIPLY = SymbolicConstant('MULTIPLY')
N1 = SymbolicConstant('N1')
N1_COSINES = SymbolicConstant('N1_COSINES')
N2 = SymbolicConstant('N2')
NATURAL_FREQUENCY_EXTRACTION = SymbolicConstant('NATURAL_FREQUENCY_EXTRACTION')
NATURAL_LOG = SymbolicConstant('NATURAL_LOG')
NEAREST_INTEGER = SymbolicConstant('NEAREST_INTEGER')
NEGATE = SymbolicConstant('NEGATE')
NEGATIVE = SymbolicConstant('NEGATIVE')
NEO_HOOKE = SymbolicConstant('NEO_HOOKE')
NEVER = SymbolicConstant('NEVER')
NEWTONIAN = SymbolicConstant('NEWTONIAN')
NEW_CONTACT_PATCH = SymbolicConstant('NEW_CONTACT_PATCH')
NMORI = SymbolicConstant('NMORI')
NO = SymbolicConstant('NO')
NODAL = SymbolicConstant('NODAL')
NODAL_ANALYTICAL_FIELD = SymbolicConstant('NODAL_ANALYTICAL_FIELD')
NODAL_AVERAGE = SymbolicConstant('NODAL_AVERAGE')
NODAL_DISCRETE_FIELD = SymbolicConstant('NODAL_DISCRETE_FIELD')
NODAL_LINE = SymbolicConstant('NODAL_LINE')
NODE = SymbolicConstant('NODE')
NODES = SymbolicConstant('NODES')
NODE_ALL = SymbolicConstant('NODE_ALL')
NODE_CENTERED = SymbolicConstant('NODE_CENTERED')
NODE_LIST = SymbolicConstant('NODE_LIST')
NODE_MODE = SymbolicConstant('NODE_MODE')
NODE_MODE_MPC = SymbolicConstant('NODE_MODE_MPC')
NODE_PRESELECT = SymbolicConstant('NODE_PRESELECT')
NODE_TO_SURFACE = SymbolicConstant('NODE_TO_SURFACE')
NONACCUMULATEDENERGY = SymbolicConstant('NONACCUMULATEDENERGY')
NONE = SymbolicConstant('NONE')
NONLINEAR = SymbolicConstant('NONLINEAR')
NONREFLECTING = SymbolicConstant('NONREFLECTING')
NONUNIFORM = SymbolicConstant('NONUNIFORM')
NON_DEFAULT = SymbolicConstant('NON_DEFAULT')
NON_REFLECTING = SymbolicConstant('NON_REFLECTING')
NORM = SymbolicConstant('NORM')
NORMAL = SymbolicConstant('NORMAL')
NORMALIZED_CONCENTRATION_FIELD = SymbolicConstant('NORMALIZED_CONCENTRATION_FIELD')
NORMALS = SymbolicConstant('NORMALS')
NORMAL_ANNOTATED = SymbolicConstant('NORMAL_ANNOTATED')
NORMAL_TANGENTIAL = SymbolicConstant('NORMAL_TANGENTIAL')
NORMAL_VECTOR = SymbolicConstant('NORMAL_VECTOR')
NORM_DISTANCE = SymbolicConstant('NORM_DISTANCE')
NORM_FIRST = SymbolicConstant('NORM_FIRST')
NOT_ALLOWED = SymbolicConstant('NOT_ALLOWED')
NOT_APPLICABLE = SymbolicConstant('NOT_APPLICABLE')
NOT_SET = SymbolicConstant('NOT_SET')
NOT_YET_ACTIVE = SymbolicConstant('NOT_YET_ACTIVE')
NO_BLOCKING = SymbolicConstant('NO_BLOCKING')
NO_EXTRAPOLATION = SymbolicConstant('NO_EXTRAPOLATION')
NO_HEAD = SymbolicConstant('NO_HEAD')
NO_IDEALIZATION = SymbolicConstant('NO_IDEALIZATION')
NO_INDEPENDENT_COMPONENTS = SymbolicConstant('NO_INDEPENDENT_COMPONENTS')
NO_INITIAL_INTERSECTION = SymbolicConstant('NO_INITIAL_INTERSECTION')
NO_LIMIT = SymbolicConstant('NO_LIMIT')
NO_LINE = SymbolicConstant('NO_LINE')
NO_LONGER_ACTIVE = SymbolicConstant('NO_LONGER_ACTIVE')
NO_OUTPUT = SymbolicConstant('NO_OUTPUT')
NO_OUTPUT_VARIABLES = SymbolicConstant('NO_OUTPUT_VARIABLES')
NO_REFINEMENT = SymbolicConstant('NO_REFINEMENT')
NO_SIMPLIFICATION = SymbolicConstant('NO_SIMPLIFICATION')
NO_SLIP = SymbolicConstant('NO_SLIP')
NRL = SymbolicConstant('NRL')
NSET_MAP = SymbolicConstant('NSET_MAP')
NT = SymbolicConstant('NT')
NTH_POWER = SymbolicConstant('NTH_POWER')
NTH_ROOT = SymbolicConstant('NTH_ROOT')
NUMBER = SymbolicConstant('NUMBER')
NUMBERS = SymbolicConstant('NUMBERS')
NUMBER_INTERVALS = SymbolicConstant('NUMBER_INTERVALS')
NUMBER_OF_LAYERS = SymbolicConstant('NUMBER_OF_LAYERS')
NUMBER_OF_VALUES = SymbolicConstant('NUMBER_OF_VALUES')
NUMERICAL_PROBLEM = SymbolicConstant('NUMERICAL_PROBLEM')
NUM_ATTEMPTS = SymbolicConstant('NUM_ATTEMPTS')
NUM_DATA_TYPE = SymbolicConstant('NUM_DATA_TYPE')
NUM_ELEMENTS_EXCEEDING = SymbolicConstant('NUM_ELEMENTS_EXCEEDING')
NUM_EQI = SymbolicConstant('NUM_EQI')
NUM_ITERS = SymbolicConstant('NUM_ITERS')
NUM_PTS_ALONG_DIR = SymbolicConstant('NUM_PTS_ALONG_DIR')
NUM_PTS_BETWEEN_PTS = SymbolicConstant('NUM_PTS_BETWEEN_PTS')
NUM_SDI = SymbolicConstant('NUM_SDI')
OBLIQUE_DOWN = SymbolicConstant('OBLIQUE_DOWN')
OBLIQUE_UP = SymbolicConstant('OBLIQUE_UP')
ODB = SymbolicConstant('ODB')
ODB_FILE = SymbolicConstant('ODB_FILE')
ODB_FRAME = SymbolicConstant('ODB_FRAME')
ODB_REGIONS = SymbolicConstant('ODB_REGIONS')
ODB_VALUES = SymbolicConstant('ODB_VALUES')
OFFSET_FIELD = SymbolicConstant('OFFSET_FIELD')
OGDEN = SymbolicConstant('OGDEN')
OGDEN_N1 = SymbolicConstant('OGDEN_N1')
OGDEN_N2 = SymbolicConstant('OGDEN_N2')
OGDEN_N3 = SymbolicConstant('OGDEN_N3')
OGDEN_N4 = SymbolicConstant('OGDEN_N4')
OGDEN_N5 = SymbolicConstant('OGDEN_N5')
OGDEN_N6 = SymbolicConstant('OGDEN_N6')
OMIT = SymbolicConstant('OMIT')
ONE_CONFIG = SymbolicConstant('ONE_CONFIG')
ONLY = SymbolicConstant('ONLY')
OPENINGS = SymbolicConstant('OPENINGS')
OPEN_GL = SymbolicConstant('OPEN_GL')
OPTIMIZATION_DISPLACEMENT = SymbolicConstant('OPTIMIZATION_DISPLACEMENT')
OPT_DATASAVE_EVERY_CYCLE = SymbolicConstant('OPT_DATASAVE_EVERY_CYCLE')
OPT_DATASAVE_FIRST_AND_LAST_CYCLE = SymbolicConstant('OPT_DATASAVE_FIRST_AND_LAST_CYCLE')
OPT_DATASAVE_SPECIFY_CYCLE = SymbolicConstant('OPT_DATASAVE_SPECIFY_CYCLE')
OPT_EXTRACT_SMOOTH_ABAQUS_INPUT_FILE = SymbolicConstant('OPT_EXTRACT_SMOOTH_ABAQUS_INPUT_FILE')
OPT_EXTRACT_SMOOTH_NONE = SymbolicConstant('OPT_EXTRACT_SMOOTH_NONE')
OPT_EXTRACT_SMOOTH_STL = SymbolicConstant('OPT_EXTRACT_SMOOTH_STL')
ORDINATE = SymbolicConstant('ORDINATE')
ORIENTATION = SymbolicConstant('ORIENTATION')
ORIENT_FIELD = SymbolicConstant('ORIENT_FIELD')
ORIENT_ON_DEF = SymbolicConstant('ORIENT_ON_DEF')
ORIENT_ON_UNDEF = SymbolicConstant('ORIENT_ON_UNDEF')
ORIGINAL = SymbolicConstant('ORIGINAL')
ORIGINAL_MODEL = SymbolicConstant('ORIGINAL_MODEL')
ORIGIN_AXIS = SymbolicConstant('ORIGIN_AXIS')
ORTHOGONAL = SymbolicConstant('ORTHOGONAL')
ORTHOTROPIC = SymbolicConstant('ORTHOTROPIC')
OTHER = SymbolicConstant('OTHER')
OTHER_BC = SymbolicConstant('OTHER_BC')
OUTFLOW = SymbolicConstant('OUTFLOW')
OUTOFPLANE_PRINCIPAL = SymbolicConstant('OUTOFPLANE_PRINCIPAL')
OUTPUT = SymbolicConstant('OUTPUT')
OUTSIDE = SymbolicConstant('OUTSIDE')
OUTWARD = SymbolicConstant('OUTWARD')
OUT_OF_PLANE_EXTENSION_RATIO_NOT_FOUND = SymbolicConstant('OUT_OF_PLANE_EXTENSION_RATIO_NOT_FOUND')
OVERCLOSED = SymbolicConstant('OVERCLOSED')
OVERCLOSURES = SymbolicConstant('OVERCLOSURES')
OVERCONSTRAINT = SymbolicConstant('OVERCONSTRAINT')
OVERHANG_REGION = SymbolicConstant('OVERHANG_REGION')
OVERLAY = SymbolicConstant('OVERLAY')
OVERWRITE = SymbolicConstant('OVERWRITE')
PACKAGER_PHASE = SymbolicConstant('PACKAGER_PHASE')
PARABOLA = SymbolicConstant('PARABOLA')
PARABOLIC = SymbolicConstant('PARABOLIC')
PARABOLIC_EXTRAPOLATION = SymbolicConstant('PARABOLIC_EXTRAPOLATION')
PARALLEL = SymbolicConstant('PARALLEL')
PARAMETERS = SymbolicConstant('PARAMETERS')
PARAMETRIC_DATA = SymbolicConstant('PARAMETRIC_DATA')
PART = SymbolicConstant('PART')
PARTIAL_BLOCKING = SymbolicConstant('PARTIAL_BLOCKING')
PARTIAL_FIELD = SymbolicConstant('PARTIAL_FIELD')
PART_ASSEMBLY = SymbolicConstant('PART_ASSEMBLY')
PART_GEOM_MAP = SymbolicConstant('PART_GEOM_MAP')
PART_GEOM_MAP_COLORS = SymbolicConstant('PART_GEOM_MAP_COLORS')
PART_MAP = SymbolicConstant('PART_MAP')
PART_MAP_COLORS = SymbolicConstant('PART_MAP_COLORS')
PATH = SymbolicConstant('PATH')
PATH_POINTS = SymbolicConstant('PATH_POINTS')
PATH_X = SymbolicConstant('PATH_X')
PATH_Y = SymbolicConstant('PATH_Y')
PATH_Z = SymbolicConstant('PATH_Z')
PATTERN_ALONG_DIRECTION = SymbolicConstant('PATTERN_ALONG_DIRECTION')
PATTERN_INVALID = SymbolicConstant('PATTERN_INVALID')
PATTERN_ORTHOGONALLY = SymbolicConstant('PATTERN_ORTHOGONALLY')
PENALTY = SymbolicConstant('PENALTY')
PENETRATION_TOLERANCE_EXCEEDED = SymbolicConstant('PENETRATION_TOLERANCE_EXCEEDED')
PERCENTAGE = SymbolicConstant('PERCENTAGE')
PERIMETER = SymbolicConstant('PERIMETER')
PERIOD = SymbolicConstant('PERIOD')
PERP = SymbolicConstant('PERP')
PERPENDICULAR = SymbolicConstant('PERPENDICULAR')
PERSPECTIVE = SymbolicConstant('PERSPECTIVE')
PERTURBATION_AND_BUCKLING = SymbolicConstant('PERTURBATION_AND_BUCKLING')
PHASE = SymbolicConstant('PHASE')
PHONG = SymbolicConstant('PHONG')
PICKED = SymbolicConstant('PICKED')
PICKEDPOINTS = SymbolicConstant('PICKEDPOINTS')
PIEZOELECTRIC = SymbolicConstant('PIEZOELECTRIC')
PIEZO_ELECTRICAL_POTENTIAL_FIELD = SymbolicConstant('PIEZO_ELECTRICAL_POTENTIAL_FIELD')
PINNED = SymbolicConstant('PINNED')
PIN_MPC = SymbolicConstant('PIN_MPC')
PIPE21 = SymbolicConstant('PIPE21')
PIPE21H = SymbolicConstant('PIPE21H')
PIPE22 = SymbolicConstant('PIPE22')
PIPE22H = SymbolicConstant('PIPE22H')
PIPE31 = SymbolicConstant('PIPE31')
PIPE31H = SymbolicConstant('PIPE31H')
PIPE32 = SymbolicConstant('PIPE32')
PIPE32H = SymbolicConstant('PIPE32H')
PLANAR = SymbolicConstant('PLANAR')
PLANE = SymbolicConstant('PLANE')
PLANE12 = SymbolicConstant('PLANE12')
PLANE13 = SymbolicConstant('PLANE13')
PLANE21 = SymbolicConstant('PLANE21')
PLANE23 = SymbolicConstant('PLANE23')
PLANE31 = SymbolicConstant('PLANE31')
PLANE32 = SymbolicConstant('PLANE32')
PLASTIC_MOTION = SymbolicConstant('PLASTIC_MOTION')
PLAY = SymbolicConstant('PLAY')
PLAY_ONCE = SymbolicConstant('PLAY_ONCE')
PLOT_MAP = SymbolicConstant('PLOT_MAP')
PLOT_MAP_COLORS = SymbolicConstant('PLOT_MAP_COLORS')
PLOT_OPTIONS = SymbolicConstant('PLOT_OPTIONS')
PLOT_STATE = SymbolicConstant('PLOT_STATE')
PLY = SymbolicConstant('PLY')
PLY_BASED = SymbolicConstant('PLY_BASED')
PLY_MAP = SymbolicConstant('PLY_MAP')
PLY_MAP_COLORS = SymbolicConstant('PLY_MAP_COLORS')
PNEUMATIC = SymbolicConstant('PNEUMATIC')
PNG = SymbolicConstant('PNG')
POINT = SymbolicConstant('POINT')
POINTLINEDIST = SymbolicConstant('POINTLINEDIST')
POINTPOINTDIST = SymbolicConstant('POINTPOINTDIST')
POINTS = SymbolicConstant('POINTS')
POINTS_NOW_SLIPPING = SymbolicConstant('POINTS_NOW_SLIPPING')
POINTS_NOW_STICKING = SymbolicConstant('POINTS_NOW_STICKING')
POINTS_THROUGH_SECTION = SymbolicConstant('POINTS_THROUGH_SECTION')
POINTWISE = SymbolicConstant('POINTWISE')
POINT_ARC = SymbolicConstant('POINT_ARC')
POINT_LIST = SymbolicConstant('POINT_LIST')
POISSON = SymbolicConstant('POISSON')
POISSON_RATIO = SymbolicConstant('POISSON_RATIO')
POLAR = SymbolicConstant('POLAR')
POLYNOMIAL = SymbolicConstant('POLYNOMIAL')
POLY_N1 = SymbolicConstant('POLY_N1')
POLY_N2 = SymbolicConstant('POLY_N2')
POLY_N3 = SymbolicConstant('POLY_N3')
POLY_N4 = SymbolicConstant('POLY_N4')
POLY_N5 = SymbolicConstant('POLY_N5')
POLY_N6 = SymbolicConstant('POLY_N6')
PORE_FLUID_CONTACT = SymbolicConstant('PORE_FLUID_CONTACT')
PORE_FLUID_DIFFUSION = SymbolicConstant('PORE_FLUID_DIFFUSION')
PORE_LIQUID_PRESSURE_FIELD = SymbolicConstant('PORE_LIQUID_PRESSURE_FIELD')
PORTRAIT = SymbolicConstant('PORTRAIT')
POSITION = SymbolicConstant('POSITION')
POSITIONS = SymbolicConstant('POSITIONS')
POSITIVE = SymbolicConstant('POSITIVE')
POWER = SymbolicConstant('POWER')
POWER_LAW = SymbolicConstant('POWER_LAW')
PREDEFINED = SymbolicConstant('PREDEFINED')
PREDEFINED_FIELD = SymbolicConstant('PREDEFINED_FIELD')
PREDEFINED_PATH = SymbolicConstant('PREDEFINED_PATH')
PRESCRIBEDCONDITION_DOF = SymbolicConstant('PRESCRIBEDCONDITION_DOF')
PRESELECT = SymbolicConstant('PRESELECT')
PRESERVE_SECTION = SymbolicConstant('PRESERVE_SECTION')
PRESS = SymbolicConstant('PRESS')
PRESSURE = SymbolicConstant('PRESSURE')
PRESSURE_GRADIENT = SymbolicConstant('PRESSURE_GRADIENT')
PRESSURE_PENETRATION = SymbolicConstant('PRESSURE_PENETRATION')
PRESSURE_STRESS_CONSTRAINT = SymbolicConstant('PRESSURE_STRESS_CONSTRAINT')
PREVIOUS = SymbolicConstant('PREVIOUS')
PREVIOUS_STEP = SymbolicConstant('PREVIOUS_STEP')
PRIMARY_VECTOR = SymbolicConstant('PRIMARY_VECTOR')
PRINCIPAL = SymbolicConstant('PRINCIPAL')
PRINCIPAL_COMPONENT = SymbolicConstant('PRINCIPAL_COMPONENT')
PRINTER = SymbolicConstant('PRINTER')
PROJECTION_CARTESIAN = SymbolicConstant('PROJECTION_CARTESIAN')
PROJECTION_FLEXION_TORSION = SymbolicConstant('PROJECTION_FLEXION_TORSION')
PROJECT_BY_DIRECTION = SymbolicConstant('PROJECT_BY_DIRECTION')
PROJECT_BY_DISTANCE = SymbolicConstant('PROJECT_BY_DISTANCE')
PROJECT_BY_NUMBER = SymbolicConstant('PROJECT_BY_NUMBER')
PROJECT_BY_PROXIMITY = SymbolicConstant('PROJECT_BY_PROXIMITY')
PROLATE = SymbolicConstant('PROLATE')
PRONY = SymbolicConstant('PRONY')
PROPAGATED = SymbolicConstant('PROPAGATED')
PROPAGATED_FROM_BASE_STATE = SymbolicConstant('PROPAGATED_FROM_BASE_STATE')
PROPAGATED_FROM_COMPUTED = SymbolicConstant('PROPAGATED_FROM_COMPUTED')
PROPAGATED_FROM_FREQUENCY = SymbolicConstant('PROPAGATED_FROM_FREQUENCY')
PROPERTY_CHANGE = SymbolicConstant('PROPERTY_CHANGE')
PROPERTY_MAP = SymbolicConstant('PROPERTY_MAP')
PROPERTY_MAP_COLORS = SymbolicConstant('PROPERTY_MAP_COLORS')
PROPERTY_REF = SymbolicConstant('PROPERTY_REF')
PS = SymbolicConstant('PS')
PSI24 = SymbolicConstant('PSI24')
PSI26 = SymbolicConstant('PSI26')
PSI34 = SymbolicConstant('PSI34')
PSI36 = SymbolicConstant('PSI36')
PS_ALWAYS = SymbolicConstant('PS_ALWAYS')
PS_IF_AVAILABLE = SymbolicConstant('PS_IF_AVAILABLE')
PYR5 = SymbolicConstant('PYR5')
Q3D10M = SymbolicConstant('Q3D10M')
Q3D10MH = SymbolicConstant('Q3D10MH')
Q3D20 = SymbolicConstant('Q3D20')
Q3D20H = SymbolicConstant('Q3D20H')
Q3D20R = SymbolicConstant('Q3D20R')
Q3D20RH = SymbolicConstant('Q3D20RH')
Q3D4 = SymbolicConstant('Q3D4')
Q3D6 = SymbolicConstant('Q3D6')
Q3D8 = SymbolicConstant('Q3D8')
Q3D8H = SymbolicConstant('Q3D8H')
Q3D8R = SymbolicConstant('Q3D8R')
Q3D8RH = SymbolicConstant('Q3D8RH')
QUAD = SymbolicConstant('QUAD')
QUAD4 = SymbolicConstant('QUAD4')
QUAD8 = SymbolicConstant('QUAD8')
QUADRATIC = SymbolicConstant('QUADRATIC')
QUADS = SymbolicConstant('QUADS')
QUAD_DOMINATED = SymbolicConstant('QUAD_DOMINATED')
QUAD_SEPARATION = SymbolicConstant('QUAD_SEPARATION')
QUAD_STRIP = SymbolicConstant('QUAD_STRIP')
QUAD_TRACTION = SymbolicConstant('QUAD_TRACTION')
QUASI_NEWTON = SymbolicConstant('QUASI_NEWTON')
QUASI_NEWTON_METHOD = SymbolicConstant('QUASI_NEWTON_METHOD')
QUASI_STATIC = SymbolicConstant('QUASI_STATIC')
QUATERNION_2D = SymbolicConstant('QUATERNION_2D')
QUATERNION_3D = SymbolicConstant('QUATERNION_3D')
QUICKTIME = SymbolicConstant('QUICKTIME')
QUILT = SymbolicConstant('QUILT')
QUINTIC = SymbolicConstant('QUINTIC')
Q_VECTORS = SymbolicConstant('Q_VECTORS')
R2D2 = SymbolicConstant('R2D2')
R3D3 = SymbolicConstant('R3D3')
R3D4 = SymbolicConstant('R3D4')
RADIAL = SymbolicConstant('RADIAL')
RADIAL_THRUST = SymbolicConstant('RADIAL_THRUST')
RADIATION_ALL = SymbolicConstant('RADIATION_ALL')
RADIUS = SymbolicConstant('RADIUS')
RAINBOW = SymbolicConstant('RAINBOW')
RAMP = SymbolicConstant('RAMP')
RANDOM_RESPONSE = SymbolicConstant('RANDOM_RESPONSE')
RANGE = SymbolicConstant('RANGE')
RASTER = SymbolicConstant('RASTER')
RATE = SymbolicConstant('RATE')
RATE_OF_CONVERGENCE_IS_SLOW = SymbolicConstant('RATE_OF_CONVERGENCE_IS_SLOW')
RAW24 = SymbolicConstant('RAW24')
RAW32 = SymbolicConstant('RAW32')
RAW8 = SymbolicConstant('RAW8')
RAW_DATA = SymbolicConstant('RAW_DATA')
RAX2 = SymbolicConstant('RAX2')
RB2D2 = SymbolicConstant('RB2D2')
RB3D2 = SymbolicConstant('RB3D2')
REAL = SymbolicConstant('REAL')
REAL_AND_IMAGINARY = SymbolicConstant('REAL_AND_IMAGINARY')
REAL_ONLY = SymbolicConstant('REAL_ONLY')
REBAR = SymbolicConstant('REBAR')
RECIEVE_PREDICTION = SymbolicConstant('RECIEVE_PREDICTION')
RECOMPUTE_EACH_FRAME = SymbolicConstant('RECOMPUTE_EACH_FRAME')
RECOMPUTE_GEOMETRY = SymbolicConstant('RECOMPUTE_GEOMETRY')
RECOVER = SymbolicConstant('RECOVER')
RECT_CIRC_MIRROR = SymbolicConstant('RECT_CIRC_MIRROR')
RECT_MIRROR_CIRC = SymbolicConstant('RECT_MIRROR_CIRC')
RECURSIVE = SymbolicConstant('RECURSIVE')
REDUCED_POLYNOMIAL = SymbolicConstant('REDUCED_POLYNOMIAL')
REDUCED_POLYNOMIAL_ALL = SymbolicConstant('REDUCED_POLYNOMIAL_ALL')
REDUCED_POLYNOMIAL_N1 = SymbolicConstant('REDUCED_POLYNOMIAL_N1')
REDUCED_POLYNOMIAL_N2 = SymbolicConstant('REDUCED_POLYNOMIAL_N2')
REDUCED_POLYNOMIAL_N3 = SymbolicConstant('REDUCED_POLYNOMIAL_N3')
REDUCED_POLYNOMIAL_N4 = SymbolicConstant('REDUCED_POLYNOMIAL_N4')
REDUCED_POLYNOMIAL_N5 = SymbolicConstant('REDUCED_POLYNOMIAL_N5')
REDUCED_POLYNOMIAL_N6 = SymbolicConstant('REDUCED_POLYNOMIAL_N6')
RED_TO_BLUE = SymbolicConstant('RED_TO_BLUE')
REEDER = SymbolicConstant('REEDER')
REFERENCE = SymbolicConstant('REFERENCE')
REGION = SymbolicConstant('REGION')
REGULAR = SymbolicConstant('REGULAR')
REGULAR_BEAM = SymbolicConstant('REGULAR_BEAM')
REGULAR_SHELL = SymbolicConstant('REGULAR_SHELL')
REINFORCEMENT = SymbolicConstant('REINFORCEMENT')
REINITIALIZE = SymbolicConstant('REINITIALIZE')
RELATIVE = SymbolicConstant('RELATIVE')
RELATIVE_EQUAL = SymbolicConstant('RELATIVE_EQUAL')
RELATIVE_GREATER_THAN_EQUAL = SymbolicConstant('RELATIVE_GREATER_THAN_EQUAL')
RELATIVE_LESS_THAN_EQUAL = SymbolicConstant('RELATIVE_LESS_THAN_EQUAL')
RELATIVE_SLOPE_DROP = SymbolicConstant('RELATIVE_SLOPE_DROP')
RELATIVE_VALUE = SymbolicConstant('RELATIVE_VALUE')
RELAXATION = SymbolicConstant('RELAXATION')
RELAXATION_TEST_DATA = SymbolicConstant('RELAXATION_TEST_DATA')
RELAX_STIFFNESS = SymbolicConstant('RELAX_STIFFNESS')
REMOVE = SymbolicConstant('REMOVE')
REPETITIVE_SDI_PATTERN = SymbolicConstant('REPETITIVE_SDI_PATTERN')
REPLACE = SymbolicConstant('REPLACE')
RESET_TO_INITIAL = SymbolicConstant('RESET_TO_INITIAL')
RESIDUAL_ACCEPTED = SymbolicConstant('RESIDUAL_ACCEPTED')
RESIDUAL_NOT_ACCEPTED = SymbolicConstant('RESIDUAL_NOT_ACCEPTED')
RESPONSE_SPECTRUM = SymbolicConstant('RESPONSE_SPECTRUM')
RESTART = SymbolicConstant('RESTART')
RESTRICTED_TASK_REGION_EQUIV_STRESS = SymbolicConstant('RESTRICTED_TASK_REGION_EQUIV_STRESS')
RESULTANT = SymbolicConstant('RESULTANT')
RETENTION_FACTOR = SymbolicConstant('RETENTION_FACTOR')
RETRACTOR = SymbolicConstant('RETRACTOR')
REVERSE = SymbolicConstant('REVERSE')
REVERSED_RAINBOW = SymbolicConstant('REVERSED_RAINBOW')
REVERSE_MIRROR = SymbolicConstant('REVERSE_MIRROR')
REVOLUTE = SymbolicConstant('REVOLUTE')
REVOLUTION = SymbolicConstant('REVOLUTION')
RIGHT = SymbolicConstant('RIGHT')
RIGID = SymbolicConstant('RIGID')
RIGID_BODY = SymbolicConstant('RIGID_BODY')
RIGID_SPRING_RIGID = SymbolicConstant('RIGID_SPRING_RIGID')
RIKS = SymbolicConstant('RIKS')
RLE24 = SymbolicConstant('RLE24')
RLE8 = SymbolicConstant('RLE8')
ROLLING = SymbolicConstant('ROLLING')
ROTARYI = SymbolicConstant('ROTARYI')
ROTARY_INERTIA = SymbolicConstant('ROTARY_INERTIA')
ROTATE = SymbolicConstant('ROTATE')
ROTATION = SymbolicConstant('ROTATION')
ROTATIONAL_ACCELERATION = SymbolicConstant('ROTATIONAL_ACCELERATION')
ROTATIONAL_VELOCITY = SymbolicConstant('ROTATIONAL_VELOCITY')
ROTATION_ACCELEROMETER = SymbolicConstant('ROTATION_ACCELEROMETER')
ROTATION_ANGLE = SymbolicConstant('ROTATION_ANGLE')
ROTATION_FIELD = SymbolicConstant('ROTATION_FIELD')
ROTATION_NONE = SymbolicConstant('ROTATION_NONE')
ROUGH = SymbolicConstant('ROUGH')
RSH = SymbolicConstant('RSH')
RSS = SymbolicConstant('RSS')
RUNNING = SymbolicConstant('RUNNING')
S1 = SymbolicConstant('S1')
S2 = SymbolicConstant('S2')
S3 = SymbolicConstant('S3')
S3R = SymbolicConstant('S3R')
S3RS = SymbolicConstant('S3RS')
S3RT = SymbolicConstant('S3RT')
S3T = SymbolicConstant('S3T')
S4 = SymbolicConstant('S4')
S4R = SymbolicConstant('S4R')
S4R5 = SymbolicConstant('S4R5')
S4RS = SymbolicConstant('S4RS')
S4RSW = SymbolicConstant('S4RSW')
S4RT = SymbolicConstant('S4RT')
S4T = SymbolicConstant('S4T')
S5 = SymbolicConstant('S5')
S6 = SymbolicConstant('S6')
S8R = SymbolicConstant('S8R')
S8R5 = SymbolicConstant('S8R5')
S8RT = SymbolicConstant('S8RT')
SAX1 = SymbolicConstant('SAX1')
SAX2 = SymbolicConstant('SAX2')
SAX2T = SymbolicConstant('SAX2T')
SAXA11 = SymbolicConstant('SAXA11')
SAXA12 = SymbolicConstant('SAXA12')
SAXA13 = SymbolicConstant('SAXA13')
SAXA14 = SymbolicConstant('SAXA14')
SAXA21 = SymbolicConstant('SAXA21')
SAXA22 = SymbolicConstant('SAXA22')
SAXA23 = SymbolicConstant('SAXA23')
SAXA24 = SymbolicConstant('SAXA24')
SC6R = SymbolicConstant('SC6R')
SC6RT = SymbolicConstant('SC6RT')
SC8R = SymbolicConstant('SC8R')
SC8RT = SymbolicConstant('SC8RT')
SCALAR = SymbolicConstant('SCALAR')
SCALE = SymbolicConstant('SCALE')
SCALE_FACTOR = SymbolicConstant('SCALE_FACTOR')
SCATTERED = SymbolicConstant('SCATTERED')
SCIENTIFIC = SymbolicConstant('SCIENTIFIC')
SCREEN = SymbolicConstant('SCREEN')
SCREEN_SIZE = SymbolicConstant('SCREEN_SIZE')
SECOND = SymbolicConstant('SECOND')
SECOND_ORDER_ADVECTION = SymbolicConstant('SECOND_ORDER_ADVECTION')
SECTION = SymbolicConstant('SECTION')
SECTION_MAP = SymbolicConstant('SECTION_MAP')
SECTION_MAP_COLORS = SymbolicConstant('SECTION_MAP_COLORS')
SECTION_PTS = SymbolicConstant('SECTION_PTS')
SEGMENTS = SymbolicConstant('SEGMENTS')
SELECTED = SymbolicConstant('SELECTED')
SELECTION_GRP_MAP = SymbolicConstant('SELECTION_GRP_MAP')
SELECTION_GRP_MAP_COLORS = SymbolicConstant('SELECTION_GRP_MAP_COLORS')
SELECTIVE = SymbolicConstant('SELECTIVE')
SELECT_ALL = SymbolicConstant('SELECT_ALL')
SELECT_BY_ANGLE = SymbolicConstant('SELECT_BY_ANGLE')
SELECT_BY_NUMBER = SymbolicConstant('SELECT_BY_NUMBER')
SELF = SymbolicConstant('SELF')
SEMI_AUTOMATIC = SymbolicConstant('SEMI_AUTOMATIC')
SEND_PREDICTION = SymbolicConstant('SEND_PREDICTION')
SEPARATE = SymbolicConstant('SEPARATE')
SEPARATED = SymbolicConstant('SEPARATED')
SEPARATED_SOLUTION = SymbolicConstant('SEPARATED_SOLUTION')
SEPARATE_TABLES = SymbolicConstant('SEPARATE_TABLES')
SEQUENTIAL_THERMAL_STRESS = SymbolicConstant('SEQUENTIAL_THERMAL_STRESS')
SEQ_ID = SymbolicConstant('SEQ_ID')
SET = SymbolicConstant('SET')
SET_EQUAL_DT = SymbolicConstant('SET_EQUAL_DT')
SET_MAP = SymbolicConstant('SET_MAP')
SET_MAP_COLORS = SymbolicConstant('SET_MAP_COLORS')
SEVERE_CONTACT_OVERCLOSURES = SymbolicConstant('SEVERE_CONTACT_OVERCLOSURES')
SEVERE_OVERCLOSURES = SymbolicConstant('SEVERE_OVERCLOSURES')
SFM3D3 = SymbolicConstant('SFM3D3')
SFM3D4 = SymbolicConstant('SFM3D4')
SFM3D4R = SymbolicConstant('SFM3D4R')
SFM3D6 = SymbolicConstant('SFM3D6')
SFM3D8 = SymbolicConstant('SFM3D8')
SFM3D8R = SymbolicConstant('SFM3D8R')
SFMAX1 = SymbolicConstant('SFMAX1')
SFMAX2 = SymbolicConstant('SFMAX2')
SFMCL6 = SymbolicConstant('SFMCL6')
SFMCL9 = SymbolicConstant('SFMCL9')
SFMGAX1 = SymbolicConstant('SFMGAX1')
SFMGAX2 = SymbolicConstant('SFMGAX2')
SHADED = SymbolicConstant('SHADED')
SHAPE_FACTOR = SymbolicConstant('SHAPE_FACTOR')
SHARED_LM_PRESSURE_FIELD = SymbolicConstant('SHARED_LM_PRESSURE_FIELD')
SHARED_LM_VOLUME_FIELD = SymbolicConstant('SHARED_LM_VOLUME_FIELD')
SHEAR = SymbolicConstant('SHEAR')
SHEARCREEP = SymbolicConstant('SHEARCREEP')
SHEARRELAXATION = SymbolicConstant('SHEARRELAXATION')
SHELL = SymbolicConstant('SHELL')
SHELL_TO_SOLID_COUPLING = SymbolicConstant('SHELL_TO_SOLID_COUPLING')
SHORT = SymbolicConstant('SHORT')
SHORTEST_EDGE = SymbolicConstant('SHORTEST_EDGE')
SHORTEST_PATH = SymbolicConstant('SHORTEST_PATH')
SHORT_FIBER = SymbolicConstant('SHORT_FIBER')
SHRINK_FIT = SymbolicConstant('SHRINK_FIT')
SHRINK_MOVEMENT = SymbolicConstant('SHRINK_MOVEMENT')
SIDE1 = SymbolicConstant('SIDE1')
SIDE2 = SymbolicConstant('SIDE2')
SIGCONT = SymbolicConstant('SIGCONT')
SIGINT = SymbolicConstant('SIGINT')
SIGN = SymbolicConstant('SIGN')
SIGTERM = SymbolicConstant('SIGTERM')
SIGTSTP = SymbolicConstant('SIGTSTP')
SIGUSR1 = SymbolicConstant('SIGUSR1')
SIGUSR2 = SymbolicConstant('SIGUSR2')
SIM = SymbolicConstant('SIM')
SIMP = SymbolicConstant('SIMP')
SIMPLE = SymbolicConstant('SIMPLE')
SIMPLESHEAR = SymbolicConstant('SIMPLESHEAR')
SIMPSON = SymbolicConstant('SIMPSON')
SIMULATION_ABORTED = SymbolicConstant('SIMULATION_ABORTED')
SIMULATION_COMPLETED = SymbolicConstant('SIMULATION_COMPLETED')
SIMULATION_INTERRUPTED = SymbolicConstant('SIMULATION_INTERRUPTED')
SIMULATION_STARTED = SymbolicConstant('SIMULATION_STARTED')
SINE = SymbolicConstant('SINE')
SINGHM = SymbolicConstant('SINGHM')
SINGLE = SymbolicConstant('SINGLE')
SINGLE_DIRECTION = SymbolicConstant('SINGLE_DIRECTION')
SINGLE_NODE = SymbolicConstant('SINGLE_NODE')
SINGLE_PRECISION = SymbolicConstant('SINGLE_PRECISION')
SINGLE_TABLE = SymbolicConstant('SINGLE_TABLE')
SINGLE_VALUE = SymbolicConstant('SINGLE_VALUE')
SIZE = SymbolicConstant('SIZE')
SIZE_ON_SCREEN = SymbolicConstant('SIZE_ON_SCREEN')
SKINS = SymbolicConstant('SKINS')
SKIN_MAP = SymbolicConstant('SKIN_MAP')
SKIN_MAP_COLORS = SymbolicConstant('SKIN_MAP_COLORS')
SLASH = SymbolicConstant('SLASH')
SLAVE = SymbolicConstant('SLAVE')
SLIDE_DISTANCE_EXCEEDED = SymbolicConstant('SLIDE_DISTANCE_EXCEEDED')
SLIDE_PLANE = SymbolicConstant('SLIDE_PLANE')
SLIDING = SymbolicConstant('SLIDING')
SLIPPED_OFF_PATCH = SymbolicConstant('SLIPPED_OFF_PATCH')
SLIPRING = SymbolicConstant('SLIPRING')
SLOT = SymbolicConstant('SLOT')
SMALL = SymbolicConstant('SMALL')
SMALLEST_ELEM_AT_CENTER = SymbolicConstant('SMALLEST_ELEM_AT_CENTER')
SMALLEST_ELEM_AT_ENDS = SymbolicConstant('SMALLEST_ELEM_AT_ENDS')
SMALLEST_ELEM_LOCATION = SymbolicConstant('SMALLEST_ELEM_LOCATION')
SMALL_ANGLE = SymbolicConstant('SMALL_ANGLE')
SMALL_ANGLE_QUAD_FACE = SymbolicConstant('SMALL_ANGLE_QUAD_FACE')
SMALL_ANGLE_TRI_FACE = SymbolicConstant('SMALL_ANGLE_TRI_FACE')
SMEAR_ABOUT_CORE = SymbolicConstant('SMEAR_ABOUT_CORE')
SMEAR_ALL_LAYERS = SymbolicConstant('SMEAR_ALL_LAYERS')
SMOOTHING_AS_IS = SymbolicConstant('SMOOTHING_AS_IS')
SMOOTHING_OFF = SymbolicConstant('SMOOTHING_OFF')
SMOOTHING_ON = SymbolicConstant('SMOOTHING_ON')
SNEG = SymbolicConstant('SNEG')
SOFTWARE_OVERLAY = SymbolicConstant('SOFTWARE_OVERLAY')
SOFT_CONTACT_INCOMPATIBILITIES = SymbolicConstant('SOFT_CONTACT_INCOMPATIBILITIES')
SOILS = SymbolicConstant('SOILS')
SOLID = SymbolicConstant('SOLID')
SOLIDWORKS = SymbolicConstant('SOLIDWORKS')
SOLUTION_APPEARS_TO_BE_DIVERGING = SymbolicConstant('SOLUTION_APPEARS_TO_BE_DIVERGING')
SOLVER_DEFAULT = SymbolicConstant('SOLVER_DEFAULT')
SPALART = SymbolicConstant('SPALART')
SPECIFIED = SymbolicConstant('SPECIFIED')
SPECIFIED_LIMIT = SymbolicConstant('SPECIFIED_LIMIT')
SPECIFIED_MODES = SymbolicConstant('SPECIFIED_MODES')
SPECIFIED_NODAL_DIAMETER = SymbolicConstant('SPECIFIED_NODAL_DIAMETER')
SPECIFY = SymbolicConstant('SPECIFY')
SPECIFY_NUM_PTS = SymbolicConstant('SPECIFY_NUM_PTS')
SPECIFY_ORIENT = SymbolicConstant('SPECIFY_ORIENT')
SPECIFY_PATH = SymbolicConstant('SPECIFY_PATH')
SPECIFY_STEP_SIZE = SymbolicConstant('SPECIFY_STEP_SIZE')
SPECIFY_THICKNESS = SymbolicConstant('SPECIFY_THICKNESS')
SPECIFY_TOLERANCE = SymbolicConstant('SPECIFY_TOLERANCE')
SPECTRUM = SymbolicConstant('SPECTRUM')
SPHERE = SymbolicConstant('SPHERE')
SPHERICAL = SymbolicConstant('SPHERICAL')
SPIN = SymbolicConstant('SPIN')
SPLINE = SymbolicConstant('SPLINE')
SPLINE_APPROXIMATION = SymbolicConstant('SPLINE_APPROXIMATION')
SPLINE_INTERPOLATION = SymbolicConstant('SPLINE_INTERPOLATION')
SPOS = SymbolicConstant('SPOS')
SPOT_WELD_CONTACT = SymbolicConstant('SPOT_WELD_CONTACT')
SPRING1 = SymbolicConstant('SPRING1')
SPRING2 = SymbolicConstant('SPRING2')
SPRINGA = SymbolicConstant('SPRINGA')
SPRING_RIGID_SPRING = SymbolicConstant('SPRING_RIGID_SPRING')
SQUARE_ROOT = SymbolicConstant('SQUARE_ROOT')
SRSS = SymbolicConstant('SRSS')
SSH = SymbolicConstant('SSH')
SSOR = SymbolicConstant('SSOR')
STABILIZATION = SymbolicConstant('STABILIZATION')
STABILIZED = SymbolicConstant('STABILIZED')
STABLE_INC_XPL = SymbolicConstant('STABLE_INC_XPL')
STABLE_TIME_INCREMENT = SymbolicConstant('STABLE_TIME_INCREMENT')
STACK_1 = SymbolicConstant('STACK_1')
STACK_2 = SymbolicConstant('STACK_2')
STACK_3 = SymbolicConstant('STACK_3')
STACK_ORIENTATION = SymbolicConstant('STACK_ORIENTATION')
STAGNATION = SymbolicConstant('STAGNATION')
STAMP = SymbolicConstant('STAMP')
STANDALONE = SymbolicConstant('STANDALONE')
STANDALONENOSHOW = SymbolicConstant('STANDALONENOSHOW')
STANDARD = SymbolicConstant('STANDARD')
STANDARD_ANALYSIS = SymbolicConstant('STANDARD_ANALYSIS')
STANDARD_EXPLICIT = SymbolicConstant('STANDARD_EXPLICIT')
STANDARD_PHASE = SymbolicConstant('STANDARD_PHASE')
START = SymbolicConstant('START')
STARTED = SymbolicConstant('STARTED')
STATE_FRAME = SymbolicConstant('STATE_FRAME')
STATIC = SymbolicConstant('STATIC')
STATIC_GENERAL = SymbolicConstant('STATIC_GENERAL')
STATIC_LINEAR_PERTURBATION = SymbolicConstant('STATIC_LINEAR_PERTURBATION')
STATIC_PERTURBATION = SymbolicConstant('STATIC_PERTURBATION')
STATIC_RIKS = SymbolicConstant('STATIC_RIKS')
STATUS = SymbolicConstant('STATUS')
STEADY_STATE = SymbolicConstant('STEADY_STATE')
STEADY_STATE_DIRECT = SymbolicConstant('STEADY_STATE_DIRECT')
STEADY_STATE_MODAL = SymbolicConstant('STEADY_STATE_MODAL')
STEADY_STATE_SUBSPACE = SymbolicConstant('STEADY_STATE_SUBSPACE')
STEADY_STATE_TRANSPORT = SymbolicConstant('STEADY_STATE_TRANSPORT')
STEP = SymbolicConstant('STEP')
STEP_END = SymbolicConstant('STEP_END')
STEP_START = SymbolicConstant('STEP_START')
STEP_TIME = SymbolicConstant('STEP_TIME')
STEP_TIME_XPL = SymbolicConstant('STEP_TIME_XPL')
STIFFNESS = SymbolicConstant('STIFFNESS')
STIFFNESS_OPTIMIZATION = SymbolicConstant('STIFFNESS_OPTIMIZATION')
STIPPLED = SymbolicConstant('STIPPLED')
STOP = SymbolicConstant('STOP')
STRAIN = SymbolicConstant('STRAIN')
STRAIN_FREE_CORRECTIONS = SymbolicConstant('STRAIN_FREE_CORRECTIONS')
STRAIN_RATE = SymbolicConstant('STRAIN_RATE')
STRESS = SymbolicConstant('STRESS')
STRESS_INTENS_FACTOR = SymbolicConstant('STRESS_INTENS_FACTOR')
STRESS_PERTURBATION = SymbolicConstant('STRESS_PERTURBATION')
STRI3 = SymbolicConstant('STRI3')
STRI65 = SymbolicConstant('STRI65')
STRINGERS = SymbolicConstant('STRINGERS')
STRINGER_MAP = SymbolicConstant('STRINGER_MAP')
STRINGER_MAP_COLORS = SymbolicConstant('STRINGER_MAP_COLORS')
STRUCTURAL = SymbolicConstant('STRUCTURAL')
STRUCTURED = SymbolicConstant('STRUCTURED')
SUBMISSION_ABORTED = SymbolicConstant('SUBMISSION_ABORTED')
SUBMITTED = SymbolicConstant('SUBMITTED')
SUBMODELING = SymbolicConstant('SUBMODELING')
SUBSPACE = SymbolicConstant('SUBSPACE')
SUBSPACE_DYNAMIC = SymbolicConstant('SUBSPACE_DYNAMIC')
SUBSPACE_EIGENSOLVER = SymbolicConstant('SUBSPACE_EIGENSOLVER')
SUBSPACE_STEADY_STATE_DYNAMIC = SymbolicConstant('SUBSPACE_STEADY_STATE_DYNAMIC')
SUBSTANCE = SymbolicConstant('SUBSTANCE')
SUBSTRUCTURE_GENERATE = SymbolicConstant('SUBSTRUCTURE_GENERATE')
SUBSTRUCTURING = SymbolicConstant('SUBSTRUCTURING')
SUBTRACT = SymbolicConstant('SUBTRACT')
SUM = SymbolicConstant('SUM')
SUPERIMPOSE = SymbolicConstant('SUPERIMPOSE')
SUPPRESS = SymbolicConstant('SUPPRESS')
SURFACE = SymbolicConstant('SURFACE')
SURFACE_BLAST = SymbolicConstant('SURFACE_BLAST')
SURFACE_INTEGRATION_POINT = SymbolicConstant('SURFACE_INTEGRATION_POINT')
SURFACE_MAP = SymbolicConstant('SURFACE_MAP')
SURFACE_MAP_COLORS = SymbolicConstant('SURFACE_MAP_COLORS')
SURFACE_NODAL = SymbolicConstant('SURFACE_NODAL')
SURFACE_POINT_EQUIV_STRESS = SymbolicConstant('SURFACE_POINT_EQUIV_STRESS')
SURFACE_TO_SURFACE = SymbolicConstant('SURFACE_TO_SURFACE')
SVG = SymbolicConstant('SVG')
SWEEP = SymbolicConstant('SWEEP')
SWING = SymbolicConstant('SWING')
SYMBOL = SymbolicConstant('SYMBOL')
SYMBOLS_ON_DEF = SymbolicConstant('SYMBOLS_ON_DEF')
SYMBOLS_ON_UNDEF = SymbolicConstant('SYMBOLS_ON_UNDEF')
SYMMETRIC = SymbolicConstant('SYMMETRIC')
SYMMETRIC_MODEL_GENERATION = SymbolicConstant('SYMMETRIC_MODEL_GENERATION')
SYNTAXCHECK = SymbolicConstant('SYNTAXCHECK')
SYSTEM = SymbolicConstant('SYSTEM')
SYSTEM_ASSIGN = SymbolicConstant('SYSTEM_ASSIGN')
SYSTEM_DEFINED = SymbolicConstant('SYSTEM_DEFINED')
T2D2 = SymbolicConstant('T2D2')
T2D2E = SymbolicConstant('T2D2E')
T2D2H = SymbolicConstant('T2D2H')
T2D2T = SymbolicConstant('T2D2T')
T2D3 = SymbolicConstant('T2D3')
T2D3E = SymbolicConstant('T2D3E')
T2D3H = SymbolicConstant('T2D3H')
T2D3T = SymbolicConstant('T2D3T')
T3D2 = SymbolicConstant('T3D2')
T3D2E = SymbolicConstant('T3D2E')
T3D2H = SymbolicConstant('T3D2H')
T3D2T = SymbolicConstant('T3D2T')
T3D3 = SymbolicConstant('T3D3')
T3D3E = SymbolicConstant('T3D3E')
T3D3H = SymbolicConstant('T3D3H')
T3D3T = SymbolicConstant('T3D3T')
TABULAR = SymbolicConstant('TABULAR')
TANGENT = SymbolicConstant('TANGENT')
TANGENTIAL = SymbolicConstant('TANGENTIAL')
TAPERED = SymbolicConstant('TAPERED')
TASK_REGION_EQUIV_STRESS = SymbolicConstant('TASK_REGION_EQUIV_STRESS')
TASK_REGION_LAYERS = SymbolicConstant('TASK_REGION_LAYERS')
TECHNIQUE = SymbolicConstant('TECHNIQUE')
TEMPERATURE = SymbolicConstant('TEMPERATURE')
TEMPERATURE_FALLEN_BELOW_ABSOLUTE_ZERO = SymbolicConstant('TEMPERATURE_FALLEN_BELOW_ABSOLUTE_ZERO')
TEMPERATURE_FIELD = SymbolicConstant('TEMPERATURE_FIELD')
TENP = SymbolicConstant('TENP')
TENSION = SymbolicConstant('TENSION')
TENSOR = SymbolicConstant('TENSOR')
TENSOR_2D_PLANAR = SymbolicConstant('TENSOR_2D_PLANAR')
TENSOR_2D_SURFACE = SymbolicConstant('TENSOR_2D_SURFACE')
TENSOR_3D_FULL = SymbolicConstant('TENSOR_3D_FULL')
TENSOR_3D_PLANAR = SymbolicConstant('TENSOR_3D_PLANAR')
TENSOR_3D_SURFACE = SymbolicConstant('TENSOR_3D_SURFACE')
TERMINATED = SymbolicConstant('TERMINATED')
TESSELLATED = SymbolicConstant('TESSELLATED')
TEST_DATA = SymbolicConstant('TEST_DATA')
TET = SymbolicConstant('TET')
TET10 = SymbolicConstant('TET10')
TET4 = SymbolicConstant('TET4')
TEXTURE_MAPPED = SymbolicConstant('TEXTURE_MAPPED')
THERMAL = SymbolicConstant('THERMAL')
THERMAL_CONTACT = SymbolicConstant('THERMAL_CONTACT')
THERMOMECHANICAL = SymbolicConstant('THERMOMECHANICAL')
THICK = SymbolicConstant('THICK')
THICKNESS = SymbolicConstant('THICKNESS')
THICKNESS_DISCRETE_FIELD = SymbolicConstant('THICKNESS_DISCRETE_FIELD')
THICKNESS_MAGNITUDE = SymbolicConstant('THICKNESS_MAGNITUDE')
THICK_WALL = SymbolicConstant('THICK_WALL')
THIN = SymbolicConstant('THIN')
THINNING = SymbolicConstant('THINNING')
THIN_WALL = SymbolicConstant('THIN_WALL')
THREADS = SymbolicConstant('THREADS')
THREED_DATA = SymbolicConstant('THREED_DATA')
THREE_D = SymbolicConstant('THREE_D')
THROUGHOUT_STEP = SymbolicConstant('THROUGHOUT_STEP')
TIE = SymbolicConstant('TIE')
TIE_MPC = SymbolicConstant('TIE_MPC')
TIFF = SymbolicConstant('TIFF')
TIGHTEN_GAPS = SymbolicConstant('TIGHTEN_GAPS')
TIME = SymbolicConstant('TIME')
TIME_AVERAGE = SymbolicConstant('TIME_AVERAGE')
TIME_BASED = SymbolicConstant('TIME_BASED')
TIME_HEAT_FLUX = SymbolicConstant('TIME_HEAT_FLUX')
TIME_HEAT_FLUX_AREA = SymbolicConstant('TIME_HEAT_FLUX_AREA')
TIME_HISTORY = SymbolicConstant('TIME_HISTORY')
TIME_INCREMENT = SymbolicConstant('TIME_INCREMENT')
TIME_INTEGRATION = SymbolicConstant('TIME_INTEGRATION')
TIME_INTEGRATION_ACCURACY_LIMIT_EXCEEDED = SymbolicConstant('TIME_INTEGRATION_ACCURACY_LIMIT_EXCEEDED')
TIME_INTEGRATION_STABILITY_LIMIT_EXCEEDED = SymbolicConstant('TIME_INTEGRATION_STABILITY_LIMIT_EXCEEDED')
TIME_INTERVAL = SymbolicConstant('TIME_INTERVAL')
TIME_INTERVAL_VALUE = SymbolicConstant('TIME_INTERVAL_VALUE')
TIME_POINT = SymbolicConstant('TIME_POINT')
TIME_VOLUME = SymbolicConstant('TIME_VOLUME')
TIME_VOLUME_FLUX = SymbolicConstant('TIME_VOLUME_FLUX')
TMORI = SymbolicConstant('TMORI')
TOLERANCE = SymbolicConstant('TOLERANCE')
TOP = SymbolicConstant('TOP')
TOP_AND_BOTTOM = SymbolicConstant('TOP_AND_BOTTOM')
TOP_CENTER = SymbolicConstant('TOP_CENTER')
TOP_LEFT = SymbolicConstant('TOP_LEFT')
TOP_RIGHT = SymbolicConstant('TOP_RIGHT')
TOP_SURFACE = SymbolicConstant('TOP_SURFACE')
TOROIDAL = SymbolicConstant('TOROIDAL')
TOTAL = SymbolicConstant('TOTAL')
TOTAL_ABSOLUTE_MOVEMENT = SymbolicConstant('TOTAL_ABSOLUTE_MOVEMENT')
TOTAL_FORCE = SymbolicConstant('TOTAL_FORCE')
TOTAL_MASS = SymbolicConstant('TOTAL_MASS')
TOTAL_MASS_XPL = SymbolicConstant('TOTAL_MASS_XPL')
TOTAL_NUM = SymbolicConstant('TOTAL_NUM')
TOTAL_NUMBER = SymbolicConstant('TOTAL_NUMBER')
TOTAL_TIME_XPL = SymbolicConstant('TOTAL_TIME_XPL')
TO_ENVIRONMENT = SymbolicConstant('TO_ENVIRONMENT')
TRACTION = SymbolicConstant('TRACTION')
TRACTION_SEPARATION = SymbolicConstant('TRACTION_SEPARATION')
TRANSFORMATION = SymbolicConstant('TRANSFORMATION')
TRANSIENT = SymbolicConstant('TRANSIENT')
TRANSIENT_FIDELITY = SymbolicConstant('TRANSIENT_FIDELITY')
TRANSLATE = SymbolicConstant('TRANSLATE')
TRANSLATOR = SymbolicConstant('TRANSLATOR')
TRANSPARENT = SymbolicConstant('TRANSPARENT')
TRANSVERSE = SymbolicConstant('TRANSVERSE')
TRANSVERSE_SHEAR_FORCE_CONSTRAINT = SymbolicConstant('TRANSVERSE_SHEAR_FORCE_CONSTRAINT')
TRAPEZOID = SymbolicConstant('TRAPEZOID')
TRESCA = SymbolicConstant('TRESCA')
TRI = SymbolicConstant('TRI')
TRIGGER = SymbolicConstant('TRIGGER')
TRI3 = SymbolicConstant('TRI3')
TRI6 = SymbolicConstant('TRI6')
TRIANGLES = SymbolicConstant('TRIANGLES')
TRIANGLE_FAN = SymbolicConstant('TRIANGLE_FAN')
TRIANGLE_STRIP = SymbolicConstant('TRIANGLE_STRIP')
TRIDIRECTIONAL = SymbolicConstant('TRIDIRECTIONAL')
TRUE_DISTANCE = SymbolicConstant('TRUE_DISTANCE')
TRUE_DISTANCE_X = SymbolicConstant('TRUE_DISTANCE_X')
TRUE_DISTANCE_Y = SymbolicConstant('TRUE_DISTANCE_Y')
TRUE_DISTANCE_Z = SymbolicConstant('TRUE_DISTANCE_Z')
TRUSS = SymbolicConstant('TRUSS')
TURB_NONE = SymbolicConstant('TURB_NONE')
TURN = SymbolicConstant('TURN')
TWIST = SymbolicConstant('TWIST')
TWO_CONFIG = SymbolicConstant('TWO_CONFIG')
TWO_D_PLANAR = SymbolicConstant('TWO_D_PLANAR')
TYPED_IN = SymbolicConstant('TYPED_IN')
TYPE_NOT_APPLICABLE = SymbolicConstant('TYPE_NOT_APPLICABLE')
T_STRESS = SymbolicConstant('T_STRESS')
U1 = SymbolicConstant('U1')
U2 = SymbolicConstant('U2')
U3 = SymbolicConstant('U3')
UJOINT = SymbolicConstant('UJOINT')
UNCHANGED = SymbolicConstant('UNCHANGED')
UNCONVERGED_CAP_PLASTICITY = SymbolicConstant('UNCONVERGED_CAP_PLASTICITY')
UNCONVERGED_CLAY_PLASTICITY = SymbolicConstant('UNCONVERGED_CLAY_PLASTICITY')
UNCONVERGED_CONCRETE_PLASTICITY = SymbolicConstant('UNCONVERGED_CONCRETE_PLASTICITY')
UNCONVERGED_CREEP_PLASTICITY = SymbolicConstant('UNCONVERGED_CREEP_PLASTICITY')
UNCONVERGED_DRUCKER_PRAGER_PLASTICITY = SymbolicConstant('UNCONVERGED_DRUCKER_PRAGER_PLASTICITY')
UNCONVERGED_FOAM_PLASTICITY = SymbolicConstant('UNCONVERGED_FOAM_PLASTICITY')
UNCONVERGED_HYPERELASTICITY = SymbolicConstant('UNCONVERGED_HYPERELASTICITY')
UNCONVERGED_METAL_PLASTICITY = SymbolicConstant('UNCONVERGED_METAL_PLASTICITY')
UNCONVERGED_MOHR_COULOMB_PLASTICITY = SymbolicConstant('UNCONVERGED_MOHR_COULOMB_PLASTICITY')
UNCORRELATED = SymbolicConstant('UNCORRELATED')
UNCOUPLED = SymbolicConstant('UNCOUPLED')
UNDEFINED_ANALYSIS = SymbolicConstant('UNDEFINED_ANALYSIS')
UNDEFINED_INVARIANT = SymbolicConstant('UNDEFINED_INVARIANT')
UNDEFINED_POSITION = SymbolicConstant('UNDEFINED_POSITION')
UNDEFORMED = SymbolicConstant('UNDEFORMED')
UNDEX = SymbolicConstant('UNDEX')
UNDEX_CHARGE = SymbolicConstant('UNDEX_CHARGE')
UNIAXIAL = SymbolicConstant('UNIAXIAL')
UNIAXIAL_VOLUMETRIC = SymbolicConstant('UNIAXIAL_VOLUMETRIC')
UNIDIRECTIONAL = SymbolicConstant('UNIDIRECTIONAL')
UNIFORM = SymbolicConstant('UNIFORM')
UNIFORM_BY_NUMBER = SymbolicConstant('UNIFORM_BY_NUMBER')
UNIFORM_BY_SIZE = SymbolicConstant('UNIFORM_BY_SIZE')
UNIFORM_ERROR = SymbolicConstant('UNIFORM_ERROR')
UNIFORM_SPACING = SymbolicConstant('UNIFORM_SPACING')
UNION = SymbolicConstant('UNION')
UNIVERSAL = SymbolicConstant('UNIVERSAL')
UNIX = SymbolicConstant('UNIX')
UNKNOWN = SymbolicConstant('UNKNOWN')
UNKNOWNAXIS = SymbolicConstant('UNKNOWNAXIS')
UNKNOWNPLANE = SymbolicConstant('UNKNOWNPLANE')
UNKNOWN_ANALYSIS_CODE = SymbolicConstant('UNKNOWN_ANALYSIS_CODE')
UNKNOWN_DIMENSION = SymbolicConstant('UNKNOWN_DIMENSION')
UNKNOWN_HEX = SymbolicConstant('UNKNOWN_HEX')
UNKNOWN_HOURGLASS_CONTROL = SymbolicConstant('UNKNOWN_HOURGLASS_CONTROL')
UNKNOWN_KINEMATIC_SPLIT = SymbolicConstant('UNKNOWN_KINEMATIC_SPLIT')
UNKNOWN_PHASE = SymbolicConstant('UNKNOWN_PHASE')
UNKNOWN_QUAD = SymbolicConstant('UNKNOWN_QUAD')
UNKNOWN_SHAPE = SymbolicConstant('UNKNOWN_SHAPE')
UNKNOWN_STRESS_RATE = SymbolicConstant('UNKNOWN_STRESS_RATE')
UNKNOWN_TET = SymbolicConstant('UNKNOWN_TET')
UNKNOWN_TRI = SymbolicConstant('UNKNOWN_TRI')
UNKNOWN_WEDGE = SymbolicConstant('UNKNOWN_WEDGE')
UNLIMITED = SymbolicConstant('UNLIMITED')
UNMESHABLE = SymbolicConstant('UNMESHABLE')
UNRESOLVED_INITIAL_OVERCLOSURES = SymbolicConstant('UNRESOLVED_INITIAL_OVERCLOSURES')
UNSET = SymbolicConstant('UNSET')
UNSPECIFIED = SymbolicConstant('UNSPECIFIED')
UNSYMMETRIC = SymbolicConstant('UNSYMMETRIC')
UR1 = SymbolicConstant('UR1')
UR2 = SymbolicConstant('UR2')
UR3 = SymbolicConstant('UR3')
USA_ADDED_MASS_GENERATION = SymbolicConstant('USA_ADDED_MASS_GENERATION')
USER = SymbolicConstant('USER')
USER_CUSTOMIZED = SymbolicConstant('USER_CUSTOMIZED')
USER_DEFINED = SymbolicConstant('USER_DEFINED')
USER_MPC = SymbolicConstant('USER_MPC')
USER_SPECIFIED = SymbolicConstant('USER_SPECIFIED')
USER_SUB = SymbolicConstant('USER_SUB')
USER_SUBROUTINE = SymbolicConstant('USER_SUBROUTINE')
USER_SUBROUTINE_REQUEST = SymbolicConstant('USER_SUBROUTINE_REQUEST')
USE_BOTTOM = SymbolicConstant('USE_BOTTOM')
USE_BOTTOM_AND_TOP = SymbolicConstant('USE_BOTTOM_AND_TOP')
USE_ENVELOPE = SymbolicConstant('USE_ENVELOPE')
USE_GEOMETRY = SymbolicConstant('USE_GEOMETRY')
USE_MESH = SymbolicConstant('USE_MESH')
USE_TOP = SymbolicConstant('USE_TOP')
USUP = SymbolicConstant('USUP')
VALUE = SymbolicConstant('VALUE')
VALUES = SymbolicConstant('VALUES')
VALUES_AND_HISTORY = SymbolicConstant('VALUES_AND_HISTORY')
VAN_DER_WAALS = SymbolicConstant('VAN_DER_WAALS')
VAN_DER_WALLS_STRETCHES_LOCKING = SymbolicConstant('VAN_DER_WALLS_STRETCHES_LOCKING')
VARIABLE_RATIO = SymbolicConstant('VARIABLE_RATIO')
VCCT = SymbolicConstant('VCCT')
VECTOR = SymbolicConstant('VECTOR')
VECTOR_COMPONENT = SymbolicConstant('VECTOR_COMPONENT')
VELOCITY = SymbolicConstant('VELOCITY')
VELOCITY_PARABOLIC = SymbolicConstant('VELOCITY_PARABOLIC')
VELOCITY_SQUARED = SymbolicConstant('VELOCITY_SQUARED')
VERTEX_ADJ_TO_SMALLEST_ELEM = SymbolicConstant('VERTEX_ADJ_TO_SMALLEST_ELEM')
VERTICAL = SymbolicConstant('VERTICAL')
VERY_SMALL = SymbolicConstant('VERY_SMALL')
VERY_THIN = SymbolicConstant('VERY_THIN')
VIEW_MANIP = SymbolicConstant('VIEW_MANIP')
VISCO = SymbolicConstant('VISCO')
VISCOUS = SymbolicConstant('VISCOUS')
VMS = SymbolicConstant('VMS')
VOID = SymbolicConstant('VOID')
VOLUME = SymbolicConstant('VOLUME')
VOLUMETRIC = SymbolicConstant('VOLUMETRIC')
VOLUMETRICCREEP = SymbolicConstant('VOLUMETRICCREEP')
VOLUMETRICRELAXATION = SymbolicConstant('VOLUMETRICRELAXATION')
VOLUMETRIC_DATA = SymbolicConstant('VOLUMETRIC_DATA')
VOLUME_COMPRESSION = SymbolicConstant('VOLUME_COMPRESSION')
VOLUME_FLUX = SymbolicConstant('VOLUME_FLUX')
VOLUME_FLUX_AREA = SymbolicConstant('VOLUME_FLUX_AREA')
VOLUME_FRACTION = SymbolicConstant('VOLUME_FRACTION')
VOLUME_PROPORTIONAL = SymbolicConstant('VOLUME_PROPORTIONAL')
VOL_FLUX = SymbolicConstant('VOL_FLUX')
VOL_RATE_LEAK = SymbolicConstant('VOL_RATE_LEAK')
VRML = SymbolicConstant('VRML')
WARNING = SymbolicConstant('WARNING')
WARP2D3 = SymbolicConstant('WARP2D3')
WARP2D4 = SymbolicConstant('WARP2D4')
WEDGE = SymbolicConstant('WEDGE')
WEDGE15 = SymbolicConstant('WEDGE15')
WEDGE6 = SymbolicConstant('WEDGE6')
WEIGHTED = SymbolicConstant('WEIGHTED')
WEIGHTED_ADD = SymbolicConstant('WEIGHTED_ADD')
WELD = SymbolicConstant('WELD')
WHITE_TO_BLACK = SymbolicConstant('WHITE_TO_BLACK')
WHOLE_ELEMENT = SymbolicConstant('WHOLE_ELEMENT')
WHOLE_MODEL = SymbolicConstant('WHOLE_MODEL')
WHOLE_PART_INSTANCE = SymbolicConstant('WHOLE_PART_INSTANCE')
WHOLE_REGION = SymbolicConstant('WHOLE_REGION')
WHOLE_SURFACE = SymbolicConstant('WHOLE_SURFACE')
WIDTH = SymbolicConstant('WIDTH')
WINDOWS = SymbolicConstant('WINDOWS')
WIRE = SymbolicConstant('WIRE')
WIREFRAME = SymbolicConstant('WIREFRAME')
WLF = SymbolicConstant('WLF')
WRAP_AROUND = SymbolicConstant('WRAP_AROUND')
X11 = SymbolicConstant('X11')
XASYMM = SymbolicConstant('XASYMM')
XAXIS = SymbolicConstant('XAXIS')
XMARKER = SymbolicConstant('XMARKER')
XOR = SymbolicConstant('XOR')
XSYMM = SymbolicConstant('XSYMM')
XYPLANE = SymbolicConstant('XYPLANE')
XYZ = SymbolicConstant('XYZ')
XZPLANE = SymbolicConstant('XZPLANE')
YASYMM = SymbolicConstant('YASYMM')
YAXIS = SymbolicConstant('YAXIS')
YEOH = SymbolicConstant('YEOH')
YIELD_RATIO = SymbolicConstant('YIELD_RATIO')
YSYMM = SymbolicConstant('YSYMM')
YZPLANE = SymbolicConstant('YZPLANE')
ZASYMM = SymbolicConstant('ZASYMM')
ZAXIS = SymbolicConstant('ZAXIS')
ZERO = SymbolicConstant('ZERO')
ZERO_PRESSURE = SymbolicConstant('ZERO_PRESSURE')
ZSYMM = SymbolicConstant('ZSYMM')
# okay decompiling abaqusConstants.pyc
